@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -326,7 +326,7 @@ public abstract class DCTree implements DocTree {
         }
     }
 
-    public static class DCEndElement extends DCTree implements EndElementTree {
+    public static class DCEndElement extends DCEndPosTree<DCStartElement> implements EndElementTree {
         public final Name name;
 
         DCEndElement(Name name) {
@@ -647,13 +647,15 @@ public abstract class DCTree implements DocTree {
 
         // The following are not directly exposed through ReferenceTree
         // use DocTrees.getElement(DocTreePath)
+        public final JCTree.JCExpression moduleName;
         public final JCTree qualifierExpression;
         public final Name memberName;
         public final List<JCTree> paramTypes;
 
 
-        DCReference(String signature, JCTree qualExpr, Name member, List<JCTree> paramTypes) {
+        DCReference(String signature, JCTree.JCExpression moduleName, JCTree qualExpr, Name member, List<JCTree> paramTypes) {
             this.signature = signature;
+            this.moduleName = moduleName;
             qualifierExpression = qualExpr;
             memberName = member;
             this.paramTypes = paramTypes;
