@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -51,9 +51,9 @@ import java.util.stream.Collectors;
 
 import jdk.internal.loader.BootLoader;
 import jdk.internal.loader.BuiltinClassLoader;
-import jdk.internal.misc.JavaLangAccess;
-import jdk.internal.misc.JavaLangModuleAccess;
-import jdk.internal.misc.SharedSecrets;
+import jdk.internal.access.JavaLangAccess;
+import jdk.internal.access.JavaLangModuleAccess;
+import jdk.internal.access.SharedSecrets;
 import jdk.internal.perf.PerfCounter;
 
 /**
@@ -140,9 +140,9 @@ public final class ModuleBootstrap {
      */
     public static ModuleLayer boot() throws Exception {
 
-        // Step 0: Command line options
+        Counters.start();
 
-        long t0 = System.nanoTime();
+        // Step 0: Command line options
 
         ModuleFinder upgradeModulePath = finderFor("jdk.module.upgrade.path");
         ModuleFinder appModulePath = finderFor("jdk.module.path");
@@ -157,6 +157,7 @@ public final class ModuleBootstrap {
         if (trace != null && Boolean.parseBoolean(trace))
             traceOutput = System.out;
 
+        Counters.add("jdk.module.boot.0.commandLineTime");
 
         // Step 1: The observable system modules, either all system modules
         // or the system modules pre-generated for the initial module (the
@@ -164,43 +165,62 @@ public final class ModuleBootstrap {
         // are pre-generated for the initial module then resolution can be
         // skipped.
 
-        long t1 = System.nanoTime();
-
         SystemModules systemModules = null;
         ModuleFinder systemModuleFinder;
 
         boolean haveModulePath = (appModulePath != null || upgradeModulePath != null);
         boolean needResolution = true;
+        boolean canArchive = false;
+        boolean hasSplitPackages;
+        boolean hasIncubatorModules;
 
-        if (!haveModulePath && addModules.isEmpty() && limitModules.isEmpty()) {
-            systemModules = SystemModuleFinders.systemModules(mainModule);
-            if (systemModules != null && !isPatched && (traceOutput == null)) {
-                needResolution = false;
-            }
-        }
-        if (systemModules == null) {
-            // all system modules are observable
-            systemModules = SystemModuleFinders.allSystemModules();
-        }
-        if (systemModules != null) {
-            // images build
-            systemModuleFinder = SystemModuleFinders.of(systemModules);
+        // If the java heap was archived at CDS dump time and the environment
+        // at dump time matches the current environment then use the archived
+        // system modules and finder.
+        ArchivedModuleGraph archivedModuleGraph = ArchivedModuleGraph.get(mainModule);
+        if (archivedModuleGraph != null
+                && !haveModulePath
+                && addModules.isEmpty()
+                && limitModules.isEmpty()
+                && !isPatched) {
+            systemModuleFinder = archivedModuleGraph.finder();
+            hasSplitPackages = archivedModuleGraph.hasSplitPackages();
+            hasIncubatorModules = archivedModuleGraph.hasIncubatorModules();
+            needResolution = (traceOutput != null);
         } else {
-            // exploded build or testing
-            systemModules = new ExplodedSystemModules();
-            systemModuleFinder = SystemModuleFinders.ofSystem();
+            if (!haveModulePath && addModules.isEmpty() && limitModules.isEmpty()) {
+                systemModules = SystemModuleFinders.systemModules(mainModule);
+                if (systemModules != null && !isPatched) {
+                    needResolution = (traceOutput != null);
+                    canArchive = true;
+                }
+            }
+            if (systemModules == null) {
+                // all system modules are observable
+                systemModules = SystemModuleFinders.allSystemModules();
+            }
+            if (systemModules != null) {
+                // images build
+                systemModuleFinder = SystemModuleFinders.of(systemModules);
+            } else {
+                // exploded build or testing
+                systemModules = new ExplodedSystemModules();
+                systemModuleFinder = SystemModuleFinders.ofSystem();
+            }
+
+            hasSplitPackages = systemModules.hasSplitPackages();
+            hasIncubatorModules = systemModules.hasIncubatorModules();
+            // not using the archived module graph - avoid accidental use
+            archivedModuleGraph = null;
         }
 
-        Counters.add("jdk.module.boot.1.systemModulesTime", t1);
-
+        Counters.add("jdk.module.boot.1.systemModulesTime");
 
         // Step 2: Define and load java.base. This patches all classes loaded
         // to date so that they are members of java.base. Once java.base is
         // loaded then resources in java.base are available for error messages
         // needed from here on.
 
-        long t2 = System.nanoTime();
-
         ModuleReference base = systemModuleFinder.find(JAVA_BASE).orElse(null);
         if (base == null)
             throw new InternalError(JAVA_BASE + " not found");
@@ -210,9 +230,6 @@ public final class ModuleBootstrap {
         BootLoader.loadModule(base);
         Modules.defineModule(null, base.descriptor(), baseUri);
 
-        Counters.add("jdk.module.boot.2.defineBaseTime", t2);
-
-
         // Step 2a: Scan all modules when --validate-modules specified
 
         if (getAndRemoveProperty("jdk.module.validation") != null) {
@@ -222,12 +239,11 @@ public final class ModuleBootstrap {
             }
         }
 
+        Counters.add("jdk.module.boot.2.defineBaseTime");
 
         // Step 3: If resolution is needed then create the module finder and
         // the set of root modules to resolve.
 
-        long t3 = System.nanoTime();
-
         ModuleFinder savedModuleFinder = null;
         ModuleFinder finder;
         Set<String> roots;
@@ -317,21 +333,23 @@ public final class ModuleBootstrap {
             roots = null;
         }
 
-        Counters.add("jdk.module.boot.3.optionsAndRootsTime", t3);
+        Counters.add("jdk.module.boot.3.optionsAndRootsTime");
 
         // Step 4: Resolve the root modules, with service binding, to create
         // the configuration for the boot layer. If resolution is not needed
         // then create the configuration for the boot layer from the
         // readability graph created at link time.
 
-        long t4 = System.nanoTime();
-
         Configuration cf;
         if (needResolution) {
-            cf = JLMA.resolveAndBind(finder, roots, traceOutput);
+            cf = Modules.newBootLayerConfiguration(finder, roots, traceOutput);
         } else {
-            Map<String, Set<String>> map = systemModules.moduleReads();
-            cf = JLMA.newConfiguration(systemModuleFinder, map);
+            if (archivedModuleGraph != null) {
+                cf = archivedModuleGraph.configuration();
+            } else {
+                Map<String, Set<String>> map = systemModules.moduleReads();
+                cf = JLMA.newConfiguration(systemModuleFinder, map);
+            }
         }
 
         // check that modules specified to --patch-module are resolved
@@ -342,8 +360,7 @@ public final class ModuleBootstrap {
                     .forEach(mn -> warnUnknownModule(PATCH_MODULE, mn));
         }
 
-        Counters.add("jdk.module.boot.4.resolveTime", t4);
-
+        Counters.add("jdk.module.boot.4.resolveTime");
 
         // Step 5: Map the modules in the configuration to class loaders.
         // The static configuration provides the mapping of standard and JDK
@@ -352,10 +369,13 @@ public final class ModuleBootstrap {
         // application module path) are defined to the application class
         // loader.
 
-        long t5 = System.nanoTime();
-
         // mapping of modules to class loaders
-        Function<String, ClassLoader> clf = ModuleLoaderMap.mappingFunction(cf);
+        Function<String, ClassLoader> clf;
+        if (archivedModuleGraph != null) {
+            clf = archivedModuleGraph.classLoaderFunction();
+        } else {
+            clf = ModuleLoaderMap.mappingFunction(cf);
+        }
 
         // check that all modules to be mapped to the boot loader will be
         // loaded from the runtime image
@@ -375,36 +395,45 @@ public final class ModuleBootstrap {
         }
 
         // check for split packages in the modules mapped to the built-in loaders
-        if (systemModules.hasSplitPackages() || isPatched || haveModulePath) {
+        if (hasSplitPackages || isPatched || haveModulePath) {
             checkSplitPackages(cf, clf);
         }
 
         // load/register the modules with the built-in class loaders
         loadModules(cf, clf);
-
-        Counters.add("jdk.module.boot.5.loadModulesTime", t5);
-
+        Counters.add("jdk.module.boot.5.loadModulesTime");
 
         // Step 6: Define all modules to the VM
 
-        long t6 = System.nanoTime();
         ModuleLayer bootLayer = ModuleLayer.empty().defineModules(cf, clf);
-        Counters.add("jdk.module.boot.6.layerCreateTime", t6);
-
+        Counters.add("jdk.module.boot.6.layerCreateTime");
 
         // Step 7: Miscellaneous
 
         // check incubating status
-        if (systemModules.hasIncubatorModules() || haveModulePath) {
+        if (hasIncubatorModules || haveModulePath) {
             checkIncubatingStatus(cf);
         }
 
         // --add-reads, --add-exports/--add-opens, and --illegal-access
-        long t7 = System.nanoTime();
         addExtraReads(bootLayer);
         boolean extraExportsOrOpens = addExtraExportsAndOpens(bootLayer);
-        addIllegalAccess(upgradeModulePath, systemModules, bootLayer, extraExportsOrOpens);
-        Counters.add("jdk.module.boot.7.adjustModulesTime", t7);
+
+        Map<String, Set<String>> concealedPackagesToOpen;
+        Map<String, Set<String>> exportedPackagesToOpen;
+        if (archivedModuleGraph != null) {
+            concealedPackagesToOpen = archivedModuleGraph.concealedPackagesToOpen();
+            exportedPackagesToOpen = archivedModuleGraph.exportedPackagesToOpen();
+        } else {
+            concealedPackagesToOpen = systemModules.concealedPackagesToOpen();
+            exportedPackagesToOpen = systemModules.exportedPackagesToOpen();
+        }
+        addIllegalAccess(upgradeModulePath,
+                         concealedPackagesToOpen,
+                         exportedPackagesToOpen,
+                         bootLayer,
+                         extraExportsOrOpens);
+        Counters.add("jdk.module.boot.7.adjustModulesTime");
 
         // save module finders for later use
         if (savedModuleFinder != null) {
@@ -413,9 +442,21 @@ public final class ModuleBootstrap {
                 limitedFinder = new SafeModuleFinder(finder);
         }
 
+        // Module graph can be archived at CDS dump time. Only allow the
+        // unnamed module case for now.
+        if (canArchive && (mainModule == null)) {
+            ArchivedModuleGraph.archive(
+                    new ArchivedModuleGraph(hasSplitPackages,
+                                            hasIncubatorModules,
+                                            systemModuleFinder,
+                                            cf,
+                                            clf,
+                                            concealedPackagesToOpen,
+                                            exportedPackagesToOpen));
+        }
+
         // total time to initialize
-        Counters.add("jdk.module.boot.totalTime", t0);
-        Counters.publish();
+        Counters.publish("jdk.module.boot.totalTime");
 
         return bootLayer;
     }
@@ -545,12 +586,13 @@ public final class ModuleBootstrap {
         // the system property is removed after decoding
         String value = getAndRemoveProperty(prefix + index);
         if (value == null) {
-            return Collections.emptySet();
+            return Set.of();
         } else {
             Set<String> modules = new HashSet<>();
             while (value != null) {
                 for (String s : value.split(",")) {
-                    if (s.length() > 0) modules.add(s);
+                    if (!s.isEmpty())
+                        modules.add(s);
                 }
                 index++;
                 value = getAndRemoveProperty(prefix + index);
@@ -565,7 +607,7 @@ public final class ModuleBootstrap {
     private static Set<String> limitModules() {
         String value = getAndRemoveProperty("jdk.module.limitmods");
         if (value == null) {
-            return Collections.emptySet();
+            return Set.of();
         } else {
             Set<String> names = new HashSet<>();
             for (String name : value.split(",")) {
@@ -701,7 +743,6 @@ public final class ModuleBootstrap {
                         Modules.addExports(m, pn, other);
                     }
                 }
-
             }
         }
     }
@@ -711,7 +752,8 @@ public final class ModuleBootstrap {
      * of system modules in the boot layer to code in unnamed modules.
      */
     private static void addIllegalAccess(ModuleFinder upgradeModulePath,
-                                         SystemModules systemModules,
+                                         Map<String, Set<String>> concealedPackagesToOpen,
+                                         Map<String, Set<String>> exportedPackagesToOpen,
                                          ModuleLayer bootLayer,
                                          boolean extraExportsOrOpens) {
         String value = getAndRemoveProperty("jdk.module.illegalAccess");
@@ -737,16 +779,15 @@ public final class ModuleBootstrap {
         IllegalAccessLogger.Builder builder
             = new IllegalAccessLogger.Builder(mode, System.err);
 
-        Map<String, Set<String>> map1 = systemModules.concealedPackagesToOpen();
-        Map<String, Set<String>> map2 = systemModules.exportedPackagesToOpen();
-        if (map1.isEmpty() && map2.isEmpty()) {
+        if (concealedPackagesToOpen.isEmpty() && exportedPackagesToOpen.isEmpty()) {
             // need to generate (exploded build)
             IllegalAccessMaps maps = IllegalAccessMaps.generate(limitedFinder());
-            map1 = maps.concealedPackagesToOpen();
-            map2 = maps.exportedPackagesToOpen();
+            concealedPackagesToOpen = maps.concealedPackagesToOpen();
+            exportedPackagesToOpen = maps.exportedPackagesToOpen();
         }
 
         // open specific packages in the system modules
+        Set<String> emptySet = Set.of();
         for (Module m : bootLayer.modules()) {
             ModuleDescriptor descriptor = m.getDescriptor();
             String name = m.getName();
@@ -762,8 +803,8 @@ public final class ModuleBootstrap {
                 continue;
             }
 
-            Set<String> concealedPackages = map1.getOrDefault(name, Set.of());
-            Set<String> exportedPackages = map2.getOrDefault(name, Set.of());
+            Set<String> concealedPackages = concealedPackagesToOpen.getOrDefault(name, emptySet);
+            Set<String> exportedPackages = exportedPackagesToOpen.getOrDefault(name, emptySet);
 
             // refresh the set of concealed and exported packages if needed
             if (extraExportsOrOpens) {
@@ -796,8 +837,7 @@ public final class ModuleBootstrap {
 
             // open the packages to unnamed modules
             JavaLangAccess jla = SharedSecrets.getJavaLangAccess();
-            jla.addOpensToAllUnnamed(m, concat(concealedPackages.iterator(),
-                                               exportedPackages.iterator()));
+            jla.addOpensToAllUnnamed(m, concealedPackages, exportedPackages);
         }
 
         builder.complete();
@@ -817,7 +857,7 @@ public final class ModuleBootstrap {
         // the system property is removed after decoding
         String value = getAndRemoveProperty(prefix + index);
         if (value == null)
-            return Collections.emptyMap();
+            return Map.of();
 
         Map<String, List<String>> map = new HashMap<>();
 
@@ -842,7 +882,7 @@ public final class ModuleBootstrap {
             List<String> values = map.computeIfAbsent(key, k -> new ArrayList<>());
             int ntargets = 0;
             for (String s : rhs.split(regex)) {
-                if (s.length() > 0) {
+                if (!s.isEmpty()) {
                     values.add(s);
                     ntargets++;
                 }
@@ -941,25 +981,6 @@ public final class ModuleBootstrap {
         }
     }
 
-    /**
-     * Returns an iterator that yields all elements of the first iterator
-     * followed by all the elements of the second iterator.
-     */
-    static <T> Iterator<T> concat(Iterator<T> iterator1, Iterator<T> iterator2) {
-        return new Iterator<T>() {
-            @Override
-            public boolean hasNext() {
-                return iterator1.hasNext() || iterator2.hasNext();
-            }
-            @Override
-            public T next() {
-                if (iterator1.hasNext()) return iterator1.next();
-                if (iterator2.hasNext()) return iterator2.next();
-                throw new NoSuchElementException();
-            }
-        };
-    }
-
     /**
      * Wraps a (potentially not thread safe) ModuleFinder created during startup
      * for use after startup.
@@ -995,6 +1016,9 @@ public final class ModuleBootstrap {
         private static final boolean PUBLISH_COUNTERS;
         private static final boolean PRINT_COUNTERS;
         private static Map<String, Long> counters;
+        private static long startTime;
+        private static long previousTime;
+
         static {
             String s = System.getProperty("jdk.module.boot.usePerfData");
             if (s == null) {
@@ -1008,27 +1032,44 @@ public final class ModuleBootstrap {
         }
 
         /**
-         * Add a counter
+         * Start counting time.
          */
-        static void add(String name, long start) {
-            if (PUBLISH_COUNTERS || PRINT_COUNTERS) {
-                counters.put(name, (System.nanoTime() - start));
+        static void start() {
+            if (PUBLISH_COUNTERS) {
+                startTime = previousTime = System.nanoTime();
+            }
+        }
+
+        /**
+         * Add a counter - storing the time difference between now and the
+         * previous add or the start.
+         */
+        static void add(String name) {
+            if (PUBLISH_COUNTERS) {
+                long current = System.nanoTime();
+                long elapsed = current - previousTime;
+                previousTime = current;
+                counters.put(name, elapsed);
             }
         }
 
         /**
          * Publish the counters to the instrumentation buffer or stdout.
          */
-        static void publish() {
-            if (PUBLISH_COUNTERS || PRINT_COUNTERS) {
+        static void publish(String totalTimeName) {
+            if (PUBLISH_COUNTERS) {
+                long currentTime = System.nanoTime();
                 for (Map.Entry<String, Long> e : counters.entrySet()) {
                     String name = e.getKey();
                     long value = e.getValue();
-                    if (PUBLISH_COUNTERS)
-                        PerfCounter.newPerfCounter(name).set(value);
+                    PerfCounter.newPerfCounter(name).set(value);
                     if (PRINT_COUNTERS)
                         System.out.println(name + " = " + value);
                 }
+                long elapsedTotal = currentTime - startTime;
+                PerfCounter.newPerfCounter(totalTimeName).set(elapsedTotal);
+                if (PRINT_COUNTERS)
+                    System.out.println(totalTimeName + " = " + elapsedTotal);
             }
         }
     }
