@@ -90,10 +90,10 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.code.HexCodeFileDisassemblerProvider,
         org.graalvm.compiler.hotspot.meta.HotSpotDisassemblerProvider,
         org.graalvm.compiler.hotspot.meta.HotSpotObjdumpDisassemblerProvider;
+    provides org.graalvm.compiler.core.common.CompilerProfiler with org.graalvm.compiler.hotspot.JFRCompilerProfiler;
     provides org.graalvm.compiler.core.match.MatchStatementSet with
         org.graalvm.compiler.core.aarch64.AArch64NodeMatchRules_MatchStatementSet,
-        org.graalvm.compiler.core.amd64.AMD64NodeMatchRules_MatchStatementSet,
-        org.graalvm.compiler.core.sparc.SPARCNodeMatchRules_MatchStatementSet;
+        org.graalvm.compiler.core.amd64.AMD64NodeMatchRules_MatchStatementSet;
     provides org.graalvm.compiler.debug.DebugHandlersFactory with org.graalvm.compiler.printer.GraalDebugHandlersFactory;
     provides org.graalvm.compiler.debug.TTYStreamProvider with org.graalvm.compiler.hotspot.HotSpotTTYStreamProvider;
     provides org.graalvm.compiler.hotspot.CompilerConfigurationFactory with
@@ -101,8 +101,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.EconomyCompilerConfigurationFactory;
     provides org.graalvm.compiler.hotspot.HotSpotBackendFactory with
         org.graalvm.compiler.hotspot.aarch64.AArch64HotSpotBackendFactory,
-        org.graalvm.compiler.hotspot.amd64.AMD64HotSpotBackendFactory,
-        org.graalvm.compiler.hotspot.sparc.SPARCHotSpotBackendFactory;
+        org.graalvm.compiler.hotspot.amd64.AMD64HotSpotBackendFactory;
     provides org.graalvm.compiler.nodes.graphbuilderconf.NodeIntrinsicPluginFactory with
         org.graalvm.compiler.hotspot.PluginFactory_HotSpotBackend,
         org.graalvm.compiler.hotspot.amd64.PluginFactory_AMD64X87MathIntrinsicNode,
@@ -114,7 +113,6 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DeoptimizeCallerNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DeoptimizeWithExceptionInCallerNode,
-        org.graalvm.compiler.hotspot.nodes.PluginFactory_DimensionsNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_EndLockScopeNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_FastAcquireBiasedLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_GraalHotSpotVMConfigNode,
@@ -139,13 +137,12 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ClassGetHubNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CounterModeSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_DigestBaseSubstitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotAllocationSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotClassSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotReplacementsUtil,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HubGetClassNode,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_IdentityHashCodeNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_Log,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_MonitorSnippets,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_NewObjectSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA2Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA5Substitutions,
@@ -186,6 +183,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.memory.PluginFactory_MemoryAnchorNode,
         org.graalvm.compiler.nodes.memory.address.PluginFactory_OffsetAddressNode,
         org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
+        org.graalvm.compiler.replacements.PluginFactory_DimensionsNode,
         org.graalvm.compiler.replacements.PluginFactory_ReplacementsUtil,
         org.graalvm.compiler.replacements.PluginFactory_SnippetCounterNode,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64FloatArithmeticSnippets,
@@ -218,6 +216,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.nodes.PluginFactory_UnaryMathIntrinsicNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ZeroMemoryNode;
     provides org.graalvm.compiler.options.OptionDescriptors with
+        org.graalvm.compiler.asm.amd64.AMD64Assembler_OptionDescriptors,
         org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
         org.graalvm.compiler.core.common.GraalOptions_OptionDescriptors,
         org.graalvm.compiler.core.common.SpeculativeExecutionAttacksMitigations_OptionDescriptors,
@@ -248,6 +247,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.HotspotSnippetsOptions_OptionDescriptors,
         org.graalvm.compiler.hotspot.stubs.CreateExceptionStub_OptionDescriptors,
         org.graalvm.compiler.hotspot.stubs.StubOptions_OptionDescriptors,
+        org.graalvm.compiler.java.BciBlockMapping_OptionDescriptors,
         org.graalvm.compiler.java.BytecodeParserOptions_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.LinearScanEliminateSpillMovePhase_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.LinearScan_OptionDescriptors,
@@ -262,6 +262,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.lir.stackslotalloc.LSStackSlotAllocator_OptionDescriptors,
         org.graalvm.compiler.loop.DefaultLoopPolicies_OptionDescriptors,
         org.graalvm.compiler.loop.LoopPolicies_OptionDescriptors,
+        org.graalvm.compiler.loop.phases.LoopFullUnrollPhase_OptionDescriptors,
         org.graalvm.compiler.nodes.util.GraphUtil_OptionDescriptors,
         org.graalvm.compiler.phases.BasePhase_OptionDescriptors,
         org.graalvm.compiler.phases.common.DeadCodeEliminationPhase_OptionDescriptors,
