@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -62,7 +62,7 @@ import org.graalvm.compiler.lir.StandardOp.LabelOp;
 import org.graalvm.compiler.lir.StandardOp.ZapRegistersOp;
 import org.graalvm.compiler.lir.SwitchStrategy;
 import org.graalvm.compiler.lir.Variable;
-import org.graalvm.compiler.lir.hashing.Hasher;
+import org.graalvm.compiler.lir.hashing.IntHasher;
 import org.graalvm.compiler.options.Option;
 import org.graalvm.compiler.options.OptionKey;
 import org.graalvm.compiler.options.OptionType;
@@ -211,7 +211,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
         return res.getRegisterConfig();
     }
 
-    @Override
     public RegisterAttributes attributes(Register register) {
         return getRegisterConfig().getAttributesMap()[register.number];
     }
@@ -294,7 +293,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
         return (Variable) value;
     }
 
-    @Override
     public Value loadNonConst(Value value) {
         if (isConstantValue(value) && !moveFactory.canInlineConstant(asConstant(value))) {
             return emitMove(value);
@@ -305,7 +303,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
     /**
      * Determines if only oop maps are required for the code generated from the LIR.
      */
-    @Override
     public boolean needOnlyOopMaps() {
         return false;
     }
@@ -318,7 +315,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
      * @return the operand representing the ABI defined location used return a value of kind
      *         {@code kind}
      */
-    @Override
     public AllocatableValue resultOperandFor(JavaKind javaKind, ValueKind<?> valueKind) {
         Register reg = getRegisterConfig().getReturnRegister(javaKind);
         assert target().arch.canStoreValue(reg.getRegisterCategory(), valueKind.getPlatformKind()) : reg.getRegisterCategory() + " " + valueKind.getPlatformKind();
@@ -327,7 +323,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
 
     NodeSourcePosition currentPosition;
 
-    @Override
     public void setSourcePosition(NodeSourcePosition position) {
         currentPosition = position;
     }
@@ -346,7 +341,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
         return op;
     }
 
-    @Override
     public boolean hasBlockEnd(AbstractBlockBase<?> block) {
         ArrayList<LIRInstruction> ops = getResult().getLIR().getLIRforBlock(block);
         if (ops.size() == 0) {
@@ -400,7 +394,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
 
     }
 
-    @Override
     public final BlockScope getBlockScope(AbstractBlockBase<?> block) {
         BlockScopeImpl blockScope = new BlockScopeImpl(block);
         blockScope.doBlockStart();
@@ -425,7 +418,6 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
         return matchScope;
     }
 
-    @Override
     public void emitIncomingValues(Value[] params) {
         ((LabelOp) res.getLIR().getLIRforBlock(getCurrentBlock()).get(0)).setIncomingValues(params);
     }
@@ -433,14 +425,11 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
     @Override
     public abstract void emitJump(LabelRef label);
 
-    @Override
     public abstract void emitCompareBranch(PlatformKind cmpKind, Value left, Value right, Condition cond, boolean unorderedIsTrue, LabelRef trueDestination, LabelRef falseDestination,
                     double trueDestinationProbability);
 
-    @Override
     public abstract void emitOverflowCheckBranch(LabelRef overflow, LabelRef noOverflow, LIRKind cmpKind, double overflowProbability);
 
-    @Override
     public abstract void emitIntegerTestBranch(Value left, Value right, LabelRef trueDestination, LabelRef falseDestination, double trueSuccessorProbability);
 
     @Override
@@ -488,14 +477,13 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
         }
     }
 
-    @Override
     public void emitStrategySwitch(JavaConstant[] keyConstants, double[] keyProbabilities, LabelRef[] keyTargets, LabelRef defaultTarget, Variable value) {
         SwitchStrategy strategy = SwitchStrategy.getBestStrategy(keyProbabilities, keyConstants, keyTargets);
 
         int keyCount = keyConstants.length;
         double minDensity = 1 / Math.sqrt(strategy.getAverageEffort());
-        Optional<Hasher> hasher = hasherFor(keyConstants, minDensity);
-        double hashTableSwitchDensity = hasher.map(h -> keyCount / (double) h.cardinality()).orElse(0d);
+        Optional<IntHasher> hasher = hasherFor(keyConstants, minDensity);
+        double hashTableSwitchDensity = hasher.map(h -> (double) keyCount / h.cardinality).orElse(0d);
         // The value range computation below may overflow, so compute it as a long.
         long valueRange = (long) keyConstants[keyCount - 1].asInt() - (long) keyConstants[0].asInt() + 1;
         double tableSwitchDensity = keyCount / (double) valueRange;
@@ -510,11 +498,10 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
             emitStrategySwitch(strategy, value, keyTargets, defaultTarget);
         } else {
             if (hashTableSwitchDensity > tableSwitchDensity) {
-                Hasher h = hasher.get();
-                int cardinality = h.cardinality();
-                LabelRef[] targets = new LabelRef[cardinality];
-                JavaConstant[] keys = new JavaConstant[cardinality];
-                for (int i = 0; i < cardinality; i++) {
+                IntHasher h = hasher.get();
+                LabelRef[] targets = new LabelRef[h.cardinality];
+                JavaConstant[] keys = new JavaConstant[h.cardinality];
+                for (int i = 0; i < h.cardinality; i++) {
                     keys[i] = JavaConstant.INT_0;
                     targets[i] = defaultTarget;
                 }
@@ -539,22 +526,24 @@ public abstract class LIRGenerator implements LIRGeneratorTool {
         }
     }
 
-    @Override
     public abstract void emitStrategySwitch(SwitchStrategy strategy, Variable key, LabelRef[] keyTargets, LabelRef defaultTarget);
 
     protected abstract void emitTableSwitch(int lowKey, LabelRef defaultTarget, LabelRef[] targets, Value key);
 
     @SuppressWarnings("unused")
-    protected Optional<Hasher> hasherFor(JavaConstant[] keyConstants, double minDensity) {
+    protected Optional<IntHasher> hasherFor(JavaConstant[] keyConstants, double minDensity) {
         return Optional.empty();
     }
 
     @SuppressWarnings("unused")
-    protected void emitHashTableSwitch(Hasher hasher, JavaConstant[] keys, LabelRef defaultTarget, LabelRef[] targets, Value value) {
+    protected void emitHashTableSwitch(IntHasher hasher, JavaConstant[] keys, LabelRef defaultTarget, LabelRef[] targets, Value value) {
         throw new UnsupportedOperationException(getClass().getSimpleName() + " doesn't support hash table switches");
     }
 
-    @Override
+    /**
+     * Called just before register allocation is performed on the LIR owned by this generator.
+     * Overriding implementations of this method must call the overridden method.
+     */
     public void beforeRegisterAllocation() {
     }
 
