@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -85,7 +85,7 @@ public class FormatData_en extends ListResourceBundle {
                "December",
                "",
             };
-        final String[] metaValue_MonthAbbreviations = new String[] {
+        final String[] metaValue_standalone_MonthAbbreviations = new String[] {
                "Jan",
                "Feb",
                "Mar",
@@ -124,7 +124,7 @@ public class FormatData_en extends ListResourceBundle {
                "Friday",
                "Saturday",
             };
-        final String[] metaValue_DayAbbreviations = new String[] {
+        final String[] metaValue_standalone_DayAbbreviations = new String[] {
                "Sun",
                "Mon",
                "Tue",
@@ -133,37 +133,18 @@ public class FormatData_en extends ListResourceBundle {
                "Fri",
                "Sat",
             };
-        final String[] metaValue_DayNarrows = new String[] {
-               "S",
-               "M",
-               "T",
-               "W",
-               "T",
-               "F",
-               "S",
-            };
         final String[] metaValue_QuarterNames = new String[] {
                "1st quarter",
                "2nd quarter",
                "3rd quarter",
                "4th quarter",
             };
-        final String[] metaValue_QuarterAbbreviations = new String[] {
+        final String[] metaValue_standalone_QuarterAbbreviations = new String[] {
                "Q1",
                "Q2",
                "Q3",
                "Q4",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "a",
                "p",
@@ -174,6 +155,10 @@ public class FormatData_en extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
@@ -190,6 +175,12 @@ public class FormatData_en extends ListResourceBundle {
                "MMM d, y GGGG",
                "M/d/y G",
             };
+        final String[] metaValue_japanese_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Before R.O.C.",
                "Minguo",
@@ -203,11 +194,10 @@ public class FormatData_en extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "year" },
             { "calendarname.islamic-umalqura", "Islamic Calendar (Umm al-Qura)" },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "calendarname.islamic-civil", "Islamic Calendar (tabular, civil epoch)" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -220,11 +210,10 @@ public class FormatData_en extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat.standard", "{0} Standard Time" },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "Japanese Calendar" },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.DayAbbreviations", metaValue_standalone_DayAbbreviations },
+            { "roc.MonthAbbreviations", metaValue_standalone_MonthAbbreviations },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
@@ -232,9 +221,9 @@ public class FormatData_en extends ListResourceBundle {
                     "Anno Domini",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_japanese_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "buddhist.MonthAbbreviations", metaValue_standalone_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
@@ -258,6 +247,8 @@ public class FormatData_en extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -265,26 +256,24 @@ public class FormatData_en extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minute" },
             { "field.era", "era" },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_japanese_QuarterNarrows },
             { "calendarname.roc", "Minguo Calendar" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "month" },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "second" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamic Calendar" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.MonthAbbreviations", metaValue_standalone_MonthAbbreviations },
             { "timezone.regionFormat", "{0} Time" },
             { "long.CompactNumberPatterns",
                 new String[] {
@@ -307,18 +296,17 @@ public class FormatData_en extends ListResourceBundle {
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_standalone_DayAbbreviations },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "time zone" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
                 new String[] {
                     "BC",
@@ -327,27 +315,35 @@ public class FormatData_en extends ListResourceBundle {
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "day of the week" },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "japanese.MonthAbbreviations", metaValue_standalone_MonthAbbreviations },
+            { "islamic.DayAbbreviations", metaValue_standalone_DayAbbreviations },
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
+            { "japanese.DayAbbreviations", metaValue_standalone_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
             { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "week" },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.DayNarrows",
+                new String[] {
+                    "S",
+                    "M",
+                    "T",
+                    "W",
+                    "T",
+                    "F",
+                    "S",
+                }
+            },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -380,9 +376,8 @@ public class FormatData_en extends ListResourceBundle {
                     "M/d/yy",
                 }
             },
-            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.DayAbbreviations", metaValue_standalone_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "hour" },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
@@ -399,8 +394,6 @@ public class FormatData_en extends ListResourceBundle {
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
