@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -206,23 +206,23 @@ public class FormatData_el extends ListResourceBundle {
             };
         final String[] metaValue_java_time_japanese_long_Eras = new String[] {
                "\u03bc\u03b5\u03c4\u03ac \u03a7\u03c1\u03b9\u03c3\u03c4\u03cc\u03bd",
-               "",
-               "",
-               "",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
                "\u03a7\u03b5\u03ca\u03c3\u03ad\u03b9",
                "\u03a1\u03ad\u03b9\u03b2\u03b1",
             };
         final String[] metaValue_java_time_japanese_Eras = new String[] {
                "\u03bc.\u03a7.",
-               "",
-               "",
-               "",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
                "\u03a7\u03b5\u03ca\u03c3\u03ad\u03b9",
                "\u03a1\u03ad\u03b9\u03b2\u03b1",
             };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u03c0\u03c1\u03bf R.O.C.",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
@@ -266,6 +266,7 @@ public class FormatData_el extends ListResourceBundle {
                     "\u03bc\u03b5\u03c4\u03ac \u03a7\u03c1\u03b9\u03c3\u03c4\u03cc\u03bd",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -284,6 +285,8 @@ public class FormatData_el extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -302,6 +305,7 @@ public class FormatData_el extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u03c0.\u03bc./\u03bc.\u03bc." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0397\u03bc\u03b5\u03c1\u03bf\u03bb\u03cc\u03b3\u03b9\u03bf \u03c4\u03b7\u03c2 \u0394\u03b7\u03bc\u03bf\u03ba\u03c1\u03b1\u03c4\u03af\u03b1\u03c2 \u03c4\u03b7\u03c2 \u039a\u03af\u03bd\u03b1\u03c2" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -312,13 +316,6 @@ public class FormatData_el extends ListResourceBundle {
             { "field.second", "\u03b4\u03b5\u03c5\u03c4\u03b5\u03c1\u03cc\u03bb\u03b5\u03c0\u03c4\u03bf" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0399\u03c3\u03bb\u03b1\u03bc\u03b9\u03ba\u03cc \u03b7\u03bc\u03b5\u03c1\u03bf\u03bb\u03cc\u03b3\u03b9\u03bf" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -348,18 +345,18 @@ public class FormatData_el extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b1",
-                    "00 \u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2",
-                    "000 \u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2",
-                    "0 \u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03bf",
-                    "00 \u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1",
-                    "000 \u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1",
-                    "0 \u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03bf",
-                    "00 \u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1",
-                    "000 \u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1",
-                    "0 \u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03bf",
-                    "00 \u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1",
-                    "000 \u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1",
+                    "{one:0' '\u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b1 other:0' '\u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2}",
+                    "{one:00' '\u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2 other:00' '\u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2}",
+                    "{one:000' '\u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2 other:000' '\u03c7\u03b9\u03bb\u03b9\u03ac\u03b4\u03b5\u03c2}",
+                    "{one:0' '\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03bf other:0' '\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:00' '\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1 other:00' '\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:000' '\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1 other:000' '\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:0' '\u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03bf other:0' '\u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:00' '\u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1 other:00' '\u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:000' '\u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1 other:000' '\u03b4\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:0' '\u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03bf other:0' '\u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:00' '\u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1 other:00' '\u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
+                    "{one:000' '\u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1 other:000' '\u03c4\u03c1\u03b9\u03c3\u03b5\u03ba\u03b1\u03c4\u03bf\u03bc\u03bc\u03cd\u03c1\u03b9\u03b1}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -414,18 +411,18 @@ public class FormatData_el extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u03c7\u03b9\u03bb'.'",
-                    "00\u00a0\u03c7\u03b9\u03bb'.'",
-                    "000\u00a0\u03c7\u03b9\u03bb'.'",
-                    "0\u00a0\u03b5\u03ba'.'",
-                    "00\u00a0\u03b5\u03ba'.'",
-                    "000\u00a0\u03b5\u03ba'.'",
-                    "0\u00a0\u03b4\u03b9\u03c3'.'",
-                    "00\u00a0\u03b4\u03b9\u03c3'.'",
-                    "000\u00a0\u03b4\u03b9\u03c3'.'",
-                    "0\u00a0\u03c4\u03c1\u03b9\u03c3'.'",
-                    "00\u00a0\u03c4\u03c1\u03b9\u03c3'.'",
-                    "000\u00a0\u03c4\u03c1\u03b9\u03c3'.'",
+                    "{one:0\u00a0\u03c7\u03b9\u03bb'.' other:0\u00a0\u03c7\u03b9\u03bb'.'}",
+                    "{one:00\u00a0\u03c7\u03b9\u03bb'.' other:00\u00a0\u03c7\u03b9\u03bb'.'}",
+                    "{one:000\u00a0\u03c7\u03b9\u03bb'.' other:000\u00a0\u03c7\u03b9\u03bb'.'}",
+                    "{one:0\u00a0\u03b5\u03ba'.' other:0\u00a0\u03b5\u03ba'.'}",
+                    "{one:00\u00a0\u03b5\u03ba'.' other:00\u00a0\u03b5\u03ba'.'}",
+                    "{one:000\u00a0\u03b5\u03ba'.' other:000\u00a0\u03b5\u03ba'.'}",
+                    "{one:0\u00a0\u03b4\u03b9\u03c3'.' other:0\u00a0\u03b4\u03b9\u03c3'.'}",
+                    "{one:00\u00a0\u03b4\u03b9\u03c3'.' other:00\u00a0\u03b4\u03b9\u03c3'.'}",
+                    "{one:000\u00a0\u03b4\u03b9\u03c3'.' other:000\u00a0\u03b4\u03b9\u03c3'.'}",
+                    "{one:0\u00a0\u03c4\u03c1\u03b9\u03c3'.' other:0\u00a0\u03c4\u03c1\u03b9\u03c3'.'}",
+                    "{one:00\u00a0\u03c4\u03c1\u03b9\u03c3'.' other:00\u00a0\u03c4\u03c1\u03b9\u03c3'.'}",
+                    "{one:000\u00a0\u03c4\u03c1\u03b9\u03c3'.' other:000\u00a0\u03c4\u03c1\u03b9\u03c3'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -463,6 +460,14 @@ public class FormatData_el extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
