@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -75,19 +75,21 @@ public class FormatData_es_GT extends ListResourceBundle {
                "p.\u00a0m.",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "G y MMMM d, EEEE",
-               "G y MMMM d",
+               "",
+               "",
                "d/MM/y G",
                "d/MM/yy GGGGG",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "GGGG y MMMM d, EEEE",
-               "GGGG y MMMM d",
+               "",
+               "",
                "d/MM/y GGGG",
                "d/MM/yy G",
             };
         final Object[][] data = new Object[][] {
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -110,6 +112,23 @@ public class FormatData_es_GT extends ListResourceBundle {
                     "d/MM/yy",
                 }
             },
+            { "latn.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "japanese.DatePatterns",
                 new String[] {
                     "EEEE, d 'de' MMMM 'de' y GGGG",
@@ -121,10 +140,16 @@ public class FormatData_es_GT extends ListResourceBundle {
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0\u00a0%",
+                    "\u00a4#,##0.00",
+                }
+            },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
