@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -233,7 +233,7 @@ public class FormatData_nb extends ListResourceBundle {
                "Minguo",
             };
         final String[] metaValue_java_time_roc_narrow_Eras = new String[] {
-               "",
+               "Before R.O.C.",
                "Minguo",
             };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
@@ -259,6 +259,8 @@ public class FormatData_nb extends ListResourceBundle {
                "\u2030",
                "\u221e",
                "NaN",
+               "",
+               "",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -279,6 +281,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.islamic-civil", "islamsk kalender (tabell, sivil)" },
@@ -295,6 +299,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -311,6 +317,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNames", metaValue_MonthNames },
@@ -341,6 +349,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "field.minute", "minutt" },
@@ -360,6 +370,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.MonthNames",
@@ -394,6 +406,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "beng.NumberPatterns", metaValue_arab_NumberPatterns },
@@ -413,6 +427,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -420,23 +436,6 @@ public class FormatData_nb extends ListResourceBundle {
             { "sund.NumberPatterns", metaValue_arab_NumberPatterns },
             { "arabext.NumberPatterns", metaValue_arab_NumberPatterns },
             { "field.second", "sekund" },
-            { "islamic.MonthNarrows",
-                new String[] {
-                    "1",
-                    "2",
-                    "3",
-                    "4",
-                    "5",
-                    "6",
-                    "7",
-                    "8",
-                    "9",
-                    "10",
-                    "11",
-                    "12",
-                    "",
-                }
-            },
             { "vaii.NumberPatterns", metaValue_arab_NumberPatterns },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamsk kalender" },
@@ -474,6 +473,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
@@ -496,6 +497,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
@@ -513,6 +516,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "TimePatterns", metaValue_TimePatterns },
@@ -532,6 +537,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "sund.NumberElements",
@@ -547,6 +554,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "telu.NumberPatterns", metaValue_arab_NumberPatterns },
@@ -564,6 +573,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNames", metaValue_DayNames },
@@ -592,6 +603,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "cakm.NumberElements", metaValue_brah_NumberElements },
@@ -608,6 +621,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "DayNames", metaValue_DayNames },
@@ -629,6 +644,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
@@ -645,6 +662,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNarrows", metaValue_DayNarrows },
@@ -679,6 +698,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -698,6 +719,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -729,6 +752,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -748,6 +773,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -767,6 +794,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "long.Eras",
@@ -789,6 +818,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -827,6 +858,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "bali.NumberElements",
@@ -842,6 +875,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
@@ -883,6 +918,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "lepc.NumberElements",
@@ -898,6 +935,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "gujr.NumberPatterns", metaValue_arab_NumberPatterns },
@@ -914,6 +953,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "limb.NumberPatterns", metaValue_arab_NumberPatterns },
@@ -931,6 +972,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "field.zone", "tidssone" },
@@ -950,6 +993,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -967,6 +1012,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "lepc.NumberPatterns", metaValue_arab_NumberPatterns },
@@ -987,6 +1034,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -1010,6 +1059,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "olck.NumberPatterns", metaValue_arab_NumberPatterns },
@@ -1029,6 +1080,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -1050,6 +1103,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
