@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -109,27 +109,12 @@ public class FormatData_ps extends ListResourceBundle {
                "\u062c\u0645\u0639\u0647",
                "\u0627\u0648\u0646\u06cd",
             };
-        final String[] metaValue_DayNarrows = new String[] {
-               "S",
-               "M",
-               "T",
-               "W",
-               "T",
-               "F",
-               "S",
-            };
         final String[] metaValue_QuarterNames = new String[] {
                "\u0644\u0648\u0645\u0693\u06cd \u0631\u0628\u0639\u0647",
                "\u06f2\u0645\u0647 \u0631\u0628\u0639\u0647",
                "\u06f3\u0645\u0647 \u0631\u0628\u0639\u0647",
                "\u06f4\u0645\u0647 \u0631\u0628\u0639\u0647",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u063a.\u0645.",
                "\u063a.\u0648.",
@@ -140,6 +125,21 @@ public class FormatData_ps extends ListResourceBundle {
                "H:mm:ss",
                "H:mm",
             };
+        final String[] metaValue_buddhist_DayNarrows = new String[] {
+               "S",
+               "M",
+               "T",
+               "W",
+               "T",
+               "F",
+               "S",
+            };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE \u062f G y \u062f MMMM d",
                "\u062f G y \u062f MMMM d",
@@ -173,6 +173,8 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -186,7 +188,7 @@ public class FormatData_ps extends ListResourceBundle {
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras",
                 new String[] {
-                    "",
+                    "BCE",
                     "\u0645.",
                 }
             },
@@ -205,7 +207,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0644\u0647 \u0645\u06cc\u0644\u0627\u062f \u0685\u062e\u0647 \u0648\u0631\u0648\u0633\u062a\u0647",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -231,6 +233,8 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -257,7 +261,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0645\u0646\u06af\u0648\u0648 \u062c\u0646\u062a\u0631\u064a" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
@@ -272,25 +276,7 @@ public class FormatData_ps extends ListResourceBundle {
                 }
             },
             { "field.second", "\u062b\u0627\u0646\u064a\u0647" },
-            { "islamic.MonthNarrows",
-                new String[] {
-                    "1",
-                    "2",
-                    "3",
-                    "4",
-                    "5",
-                    "6",
-                    "7",
-                    "8",
-                    "9",
-                    "10",
-                    "11",
-                    "12",
-                    "",
-                }
-            },
             { "DayAbbreviations", metaValue_DayNames },
-            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -332,15 +318,15 @@ public class FormatData_ps extends ListResourceBundle {
                     "{one:000T other:000T}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayNames },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "islamic.DayNarrows", metaValue_buddhist_DayNarrows },
             { "field.zone", "\u0648\u062e\u062a \u0633\u064a\u0645\u0647" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -353,7 +339,6 @@ public class FormatData_ps extends ListResourceBundle {
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u062f \u0627\u0648\u0646\u06cd \u0648\u0631\u0681" },
@@ -371,8 +356,8 @@ public class FormatData_ps extends ListResourceBundle {
             { "field.week", "\u0627\u0648\u0646\u06cd" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.DayNarrows", metaValue_DayNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "roc.DayNarrows", metaValue_buddhist_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -454,11 +439,11 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u00a4#,##0.00;(\u00a4#,##0.00)",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "buddhist.DayNarrows", metaValue_buddhist_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
-            { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
+            { "japanese.DayNarrows", metaValue_buddhist_DayNarrows },
             { "QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
