@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,12 +154,6 @@ public class FormatData_sq extends ListResourceBundle {
                "tremujori III",
                "tremujori IV",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "e paradites",
                "e pasdites",
@@ -178,6 +172,12 @@ public class FormatData_sq extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMM y G",
                "d MMM y G",
@@ -235,7 +235,7 @@ public class FormatData_sq extends ListResourceBundle {
                     "mbas Krishtit",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -261,6 +261,8 @@ public class FormatData_sq extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -271,7 +273,7 @@ public class FormatData_sq extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "paradite/pasdite" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "kalendar minguo (i Republik\u00ebs s\u00eb Kin\u00ebs)" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -304,8 +306,8 @@ public class FormatData_sq extends ListResourceBundle {
                     "{one:000' 'bilion other:000' 'bilion}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames",
                 new String[] {
                     "Tremujori i 1-r\u00eb",
@@ -328,7 +330,6 @@ public class FormatData_sq extends ListResourceBundle {
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "dit\u00eb e jav\u00ebs" },
@@ -344,7 +345,7 @@ public class FormatData_sq extends ListResourceBundle {
             { "field.week", "jav\u00eb" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
