@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,12 +154,6 @@ public class FormatData_sv extends ListResourceBundle {
                "K3",
                "K4",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "fm",
                "em",
@@ -180,6 +174,12 @@ public class FormatData_sv extends ListResourceBundle {
                "{1} {0}",
                "{1} {0}",
             };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "Buddhistisk era",
@@ -260,6 +260,8 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -288,7 +290,7 @@ public class FormatData_sv extends ListResourceBundle {
                     "efter Kristus",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -307,6 +309,8 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -335,7 +339,7 @@ public class FormatData_sv extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -349,6 +353,8 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u0609\u200f",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.roc", "kinesiska republikens kalender" },
@@ -389,8 +395,8 @@ public class FormatData_sv extends ListResourceBundle {
                     "{one:000' 'biljoner other:000' 'biljoner}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -413,6 +419,8 @@ public class FormatData_sv extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
@@ -433,7 +441,6 @@ public class FormatData_sv extends ListResourceBundle {
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "veckodag" },
@@ -456,7 +463,7 @@ public class FormatData_sv extends ListResourceBundle {
             { "field.week", "vecka" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
