@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -100,21 +100,6 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                "12\u6708",
                "",
             };
-        final String[] metaValue_MonthNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-               "5",
-               "6",
-               "7",
-               "8",
-               "9",
-               "10",
-               "11",
-               "12",
-               "",
-            };
         final String[] metaValue_DayNames = new String[] {
                "\u661f\u671f\u65e5",
                "\u661f\u671f\u4e00",
@@ -148,12 +133,6 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                "\u7b2c3\u5b63",
                "\u7b2c4\u5b63",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u4e0a\u5348",
                "\u4e0b\u5348",
@@ -174,6 +153,27 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                "{1} {0}",
                "{1} {0}",
             };
+        final String[] metaValue_buddhist_MonthNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+               "5",
+               "6",
+               "7",
+               "8",
+               "9",
+               "10",
+               "11",
+               "12",
+               "",
+            };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u4f5b\u5386",
@@ -244,7 +244,7 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             },
             { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
+            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "calendarname.islamic-civil", "\u4f0a\u65af\u5170\u6c11\u7528\u5386" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -258,7 +258,7 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -277,9 +277,10 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u975e\u6570\u503c",
+                    "",
+                    "",
                 }
             },
-            { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns",
                 new String[] {
                     "GGGGy\u5e74M\u6708d\u65e5EEEE",
@@ -295,7 +296,7 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u4e0a\u5348/\u4e0b\u5348" },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u6c11\u56fd\u5386" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -311,23 +312,6 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u79d2" },
-            { "islamic.MonthNarrows",
-                new String[] {
-                    "1",
-                    "2",
-                    "3",
-                    "4",
-                    "5",
-                    "6",
-                    "7",
-                    "8",
-                    "9",
-                    "10",
-                    "11",
-                    "12",
-                    "",
-                }
-            },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns",
@@ -346,10 +330,10 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "timezone.regionFormat", "{0}\u65f6\u95f4" },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
@@ -386,11 +370,12 @@ public class FormatData_yue_Hans extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns",
                 new String[] {
@@ -423,9 +408,9 @@ public class FormatData_yue_Hans extends ListResourceBundle {
             { "roc.MonthNames", metaValue_MonthNames },
             { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u5468" },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.buddhist.DatePatterns",
