@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -210,6 +210,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "type.ca.persian", "Persian Calendar" },
             { "type.nu.hebr", "Hebrew Numerals" },
             { "CA", "Canada" },
+            { "Kits", "Khitan small script" },
             { "CC", "Cocos (Keeling) Islands" },
             { "mzn", "Mazanderani" },
             { "CD", "Congo - Kinshasa" },
@@ -502,6 +503,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "MQ", "Martinique" },
             { "MR", "Mauritania" },
             { "MS", "Montserrat" },
+            { "Chrs", "Chorasmian" },
             { "MT", "Malta" },
             { "cps", "Capiznon" },
             { "type.m0.ungegn", "UN GEGN Transliteration" },
@@ -786,6 +788,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "061", "Polynesia" },
             { "type.kv.punct", "Ignore Symbols affects spaces and punctuation only" },
             { "%%KSCOR", "Standard Orthography" },
+            { "type.nu.segment", "Segmented Digits" },
             { "XK", "Kosovo" },
             { "type.nu.brah", "Brahmi Digits" },
             { "Gujr", metaValue_gu },
@@ -880,6 +883,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Guru", "Gurmukhi" },
             { "%%ALUKU", "Aluku dialect" },
             { "type.d0.null", "No Change" },
+            { "type.nu.diak", "Dives Akuru Digits" },
             { "lua", "Luba-Lulua" },
             { "type.kv.currency", "Ignore Symbols affects spaces, punctuation, all symbols" },
             { "type.nu.tirh", "Tirhuta Digits" },
@@ -913,6 +917,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "scn", "Sicilian" },
             { "aa", "Afar" },
             { "ab", "Abkhazian" },
+            { "Aran", "Nastaliq" },
             { "bbc", "Batak Toba" },
             { "ae", metaValue_ae },
             { "af", "Afrikaans" },
@@ -1492,6 +1497,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "type.k0.googlevk", "Google Virtual Keyboard" },
             { "Egyd", "Egyptian demotic" },
             { "Egyh", "Egyptian hieratic" },
+            { "Yezi", "Yezidi" },
             { "Palm", "Palmyrene" },
             { "ebu", "Embu" },
             { "Egyp", "Egyptian hieroglyphs" },
@@ -1514,6 +1520,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "ilo", "Iloko" },
             { "%%VALENCIA", "Valencian" },
             { "Cprt", "Cypriot" },
+            { "Diak", "Dives Akuru" },
             { "%%BAKU1926", "Unified Turkic Latin Alphabet" },
             { "%%IJEKAVSK", "Serbian with Ijekavian pronunciation" },
             { "mua", "Mundang" },
