@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,294 +70,293 @@ import sun.util.resources.OpenListResourceBundle;
 public class CurrencyNames_it extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String metaValue_CNH = "CNH";
         final Object[][] data = new Object[][] {
-            { "mwk", "kwacha malawiano" },
-            { "aon", "nuovo kwanza angolano (1990\u20132000)" },
+            { "BRL", "BRL" },
+            { "CNH", "CNH" },
+            { "HKD", "HKD" },
+            { "JPY", "JPY" },
+            { "KRW", "KRW" },
+            { "MRU", "MRU" },
             { "MXN", "MXN" },
-            { "lul", "franco finanziario del Lussemburgo" },
-            { "bad", "dinar Bosnia-Herzegovina" },
-            { "aor", "kwanza reajustado angolano (1995\u20131999)" },
-            { "mga", "ariary malgascio" },
-            { "nic", "cordoba nicaraguense" },
-            { "fim", "markka finlandese" },
+            { "PLN", "PLN" },
             { "STN", "STN" },
-            { "dem", "marco tedesco" },
-            { "mgf", "franco malgascio" },
-            { "bam", "marco convertibile della Bosnia-Herzegovina" },
-            { "egp", "sterlina egiziana" },
-            { "ssp", "sterlina sud-sudanese" },
-            { "brc", "cruzado brasiliano" },
-            { "brb", "cruzeiro novo brasiliano (1967\u20131986)" },
-            { "bre", "cruzeiro brasiliano (1990\u20131993)" },
-            { "nio", "c\u00f3rdoba nicaraguense" },
-            { "nzd", "dollaro neozelandese" },
-            { "brl", "real brasiliano" },
-            { "brn", "cruzado novo brasiliano" },
-            { "TWD", "TWD" },
-            { "ugs", "scellino ugandese (1966\u20131987)" },
-            { "fjd", "dollaro delle Figi" },
-            { "mxn", "peso messicano" },
-            { "std", "dobra di Sao Tom\u00e9 e Principe (1977\u20132017)" },
-            { "brr", "cruzeiro brasiliano" },
-            { "lvl", "lats lettone" },
-            { "scr", "rupia delle Seychelles" },
-            { "cdf", "franco congolese" },
-            { "mxp", "peso messicano d\u2019argento (1861\u20131992)" },
-            { "zal", "rand sudafricano (finanziario)" },
-            { "bbd", "dollaro di Barbados" },
-            { "hnl", "lempira honduregna" },
-            { "ugx", "scellino ugandese" },
-            { "lvr", "rublo lettone" },
-            { "mxv", "unidad de inversion (UDI) messicana" },
-            { "zar", "rand sudafricano" },
-            { "stn", "dobra di Sao Tom\u00e9 e Pr\u00edncipe" },
-            { "cuc", "peso cubano convertibile" },
-            { "bsd", "dollaro delle Bahamas" },
-            { "sdd", "dinaro sudanese" },
-            { "sdg", "sterlina sudanese" },
-            { "zrn", "nuovo zaire dello Zaire" },
-            { "iqd", "dinaro iracheno" },
-            { "cup", "peso cubano" },
-            { "gmd", "dalasi gambiano" },
-            { "twd", "nuovo dollaro taiwanese" },
-            { "rsd", "dinaro serbo" },
-            { "zrz", "zaire dello Zaire" },
-            { "uyi", "peso uruguaiano in unit\u00e0 indicizzate" },
-            { "myr", "ringgit malese" },
-            { "fkp", "sterlina delle Falkland" },
-            { "uyp", "peso uruguaiano (1975\u20131993)" },
-            { "xof", "franco CFA BCEAO" },
             { "THB", "\u0e3f" },
-            { "uyu", "peso uruguayano" },
+            { "TWD", "TWD" },
+            { "USD", "USD" },
+            { "VES", "VES" },
+            { "adp", "peseta andorrana" },
+            { "aed", "dirham degli Emirati Arabi Uniti" },
+            { "afa", "afgani (1927\u20132002)" },
+            { "afn", "afghani" },
+            { "all", "lek albanese" },
+            { "amd", "dram armeno" },
+            { "ang", "fiorino delle Antille olandesi" },
+            { "aoa", "kwanza angolano" },
+            { "aok", "kwanza angolano (1977\u20131990)" },
+            { "aon", "nuovo kwanza angolano (1990\u20132000)" },
+            { "aor", "kwanza reajustado angolano (1995\u20131999)" },
             { "ara", "austral argentino" },
-            { "sur", "rublo sovietico" },
-            { "cve", "escudo capoverdiano" },
-            { "omr", "rial omanita" },
-            { "kes", "scellino keniota" },
-            { "sek", "corona svedese" },
-            { "mze", "escudo del Mozambico" },
-            { "btn", "ngultrum bhutanese" },
             { "arp", "peso argentino (vecchio Cod.)" },
-            { "gnf", "franco della Guinea" },
-            { "mzn", "metical mozambicano" },
-            { "svc", "col\u00f3n salvadoregno" },
             { "ars", "peso argentino" },
-            { "qar", "rial qatariano" },
-            { "irr", "rial iraniano" },
-            { "nlg", "fiorino olandese" },
-            { "gns", "syli della Guinea" },
-            { "xpd", "palladio" },
-            { "thb", "baht thailandese" },
-            { "uzs", "sum uzbeco" },
-            { "xpf", "franco CFP" },
+            { "ats", "scellino austriaco" },
+            { "aud", "dollaro australiano" },
+            { "awg", "fiorino di Aruba" },
+            { "azm", "manat azero (1993\u20132006)" },
+            { "azn", "manat azero" },
+            { "bad", "dinar Bosnia-Herzegovina" },
+            { "bam", "marco convertibile della Bosnia-Herzegovina" },
+            { "bbd", "dollaro di Barbados" },
             { "bdt", "taka bangladese" },
-            { "lyd", "dinaro libico" },
-            { "buk", "kyat birmano" },
-            { "kwd", "dinaro kuwaitiano" },
-            { "xpt", "platino" },
-            { "rub", "rublo russo" },
-            { "isk", "corona islandese" },
             { "bec", "franco belga (convertibile)" },
             { "bef", "franco belga" },
-            { "mkd", "denar macedone" },
             { "bel", "franco belga (finanziario)" },
-            { "rur", "rublo della CSI" },
-            { "dzd", "dinaro algerino" },
-            { "pab", "balboa panamense" },
-            { "sgd", "dollaro di Singapore" },
-            { "kgs", "som kirghiso" },
-            { "hrd", "dinaro croato" },
-            { "xaf", "franco CFA BEAC" },
-            { "xag", "argento" },
-            { "chf", "franco svizzero" },
-            { "hrk", "kuna croata" },
-            { "itl", "lira italiana" },
-            { "ats", "scellino austriaco" },
-            { "djf", "franco di Gibuti" },
-            { "mlf", "franco di Mali" },
-            { "xre", "fondi RINET" },
-            { "adp", "peseta andorrana" },
-            { "tzs", "scellino della Tanzania" },
-            { "vnd", "dong vietnamita" },
-            { "xau", "oro" },
-            { "aud", "dollaro australiano" },
-            { "khr", "riel cambogiano" },
-            { "idr", "rupia indonesiana" },
-            { "xba", "unit\u00e0 composita europea" },
-            { "kyd", "dollaro delle Isole Cayman" },
-            { "xbc", "unit\u00e0 di acconto europea (XBC)" },
-            { "ydd", "dinaro dello Yemen" },
-            { "xbb", "unit\u00e0 monetaria europea" },
-            { "bwp", "pula del Botswana" },
-            { "gqe", "ekwele della Guinea Equatoriale" },
-            { "shp", "sterlina di Sant\u2019Elena" },
-            { "cyp", "sterlina cipriota" },
-            { "xbd", "unit\u00e0 di acconto europea (XBD)" },
-            { "tjs", "somoni tagiko" },
-            { "tjr", "rublo del Tajikistan" },
-            { "rwf", "franco ruandese" },
-            { "aed", "dirham degli Emirati Arabi Uniti" },
-            { "dkk", "corona danese" },
             { "bgl", "lev bulgaro (1962\u20131999)" },
-            { "zwd", "dollaro dello Zimbabwe" },
             { "bgn", "lev bulgaro" },
-            { "yud", "dinaro forte yugoslavo" },
-            { "mmk", "kyat di Myanmar" },
-            { "nok", "corona norvegese" },
-            { "syp", "lira siriana" },
-            { "zwl", "dollaro zimbabwiano (2009)" },
-            { "yum", "dinaro noviy yugoslavo" },
-            { "lkr", "rupia di Sri Lanka" },
-            { "yun", "dinaro convertibile yugoslavo" },
-            { "czk", "corona ceca" },
-            { "iep", "sterlina irlandese" },
-            { "grd", "dracma greca" },
-            { "xcd", "dollaro dei Caraibi orientali" },
-            { "htg", "gourde haitiano" },
-            { "afa", "afgani (1927\u20132002)" },
             { "bhd", "dinaro del Bahrein" },
-            { "sit", "tallero sloveno" },
-            { "pte", "escudo portoghese" },
-            { "kzt", "tenge kazako" },
-            { "szl", "lilangeni dello Swaziland" },
-            { "yer", "riyal yemenita" },
-            { "afn", "afghani" },
-            { "byb", "nuovo rublo bielorusso (1994\u20131999)" },
-            { "rhd", "dollaro della Rhodesia" },
-            { "awg", "fiorino di Aruba" },
-            { "npr", "rupia nepalese" },
-            { "mnt", "tugrik mongolo" },
-            { "gbp", "sterlina britannica" },
-            { "byn", "rublo bielorusso" },
-            { "xts", "codice di verifica della valuta" },
-            { "huf", "fiorino ungherese" },
-            { "byr", "rublo bielorusso (2000\u20132016)" },
             { "bif", "franco del Burundi" },
-            { "xdr", "diritti speciali di incasso" },
-            { "bzd", "dollaro del Belize" },
-            { "mop", "pataca di Macao" },
-            { "nad", "dollaro namibiano" },
-            { "skk", "corona slovacca" },
-            { "pei", "inti peruviano" },
-            { "tmm", "manat turkmeno (1993\u20132009)" },
-            { "pen", "sol peruviano" },
-            { "wst", "tala samoano" },
-            { "tmt", "manat turkmeno" },
-            { "frf", "franco francese" },
-            { "clf", "unidades de fomento chilene" },
-            { "pes", "sol peruviano (1863\u20131965)" },
-            { "gtq", "quetzal guatemalteco" },
-            { "clp", "peso cileno" },
-            { "tnd", "dinaro tunisino" },
-            { "sll", "leone della Sierra Leone" },
-            { "CNH", metaValue_CNH },
-            { "xfo", "franco oro francese" },
-            { "dop", "peso dominicano" },
-            { "kmf", "franco comoriano" },
-            { "xfu", "franco UIC francese" },
-            { "gek", "kupon larit georgiano" },
-            { "gel", "lari georgiano" },
-            { "MRU", "MRU" },
-            { "mad", "dirham marocchino" },
-            { "maf", "franco marocchino" },
-            { "azn", "manat azero" },
-            { "top", "pa\u02bbanga tongano" },
-            { "azm", "manat azero (1993\u20132006)" },
-            { "pgk", "kina papuana" },
-            { "cnh", metaValue_CNH },
-            { "uah", "grivnia ucraina" },
-            { "uak", "karbovanetz ucraino" },
-            { "ern", "nakfa eritreo" },
-            { "USD", "USD" },
-            { "tpe", "escudo di Timor" },
-            { "mro", "ouguiya della Mauritania (1973\u20132017)" },
-            { "cny", "renminbi cinese" },
-            { "mru", "ouguiya della Mauritania" },
-            { "esa", "peseta spagnola account" },
-            { "gwe", "escudo della Guinea portoghese" },
-            { "esb", "peseta spagnola account convertibile" },
             { "bmd", "dollaro delle Bermuda" },
-            { "php", "peso filippino" },
-            { "xxx", "valuta sconosciuta" },
-            { "pyg", "guaran\u00ed paraguayano" },
-            { "jmd", "dollaro giamaicano" },
-            { "gwp", "peso della Guinea-Bissau" },
-            { "esp", "peseta spagnola" },
-            { "VES", "VES" },
-            { "cop", "peso colombiano" },
-            { "usd", "dollaro statunitense" },
-            { "usn", "dollaro statunitense (next day)" },
-            { "etb", "birr etiope" },
-            { "veb", "bolivar venezuelano (1871\u20132008)" },
-            { "ecs", "sucre dell\u2019Ecuador" },
-            { "uss", "dollaro statunitense (same day)" },
-            { "sos", "scellino somalo" },
-            { "vef", "bol\u00edvar venezuelano (2008\u20132018)" },
-            { "vuv", "vatu di Vanuatu" },
-            { "lak", "kip laotiano" },
             { "bnd", "dollaro del Brunei" },
-            { "ecv", "unidad de valor constante (UVC) dell\u2019Ecuador" },
-            { "zmk", "kwacha dello Zambia (1968\u20132012)" },
-            { "lrd", "dollaro liberiano" },
-            { "HKD", "HKD" },
-            { "all", "lek albanese" },
-            { "ghc", "cedi del Ghana" },
-            { "mtl", "lira maltese" },
-            { "ves", "bol\u00edvar venezuelano" },
-            { "zmw", "kwacha dello Zambia" },
-            { "mtp", "sterlina maltese" },
-            { "ilp", "sterlina israeliana" },
-            { "trl", "lira turca (1922\u20132005)" },
-            { "ils", "nuovo siclo israeliano" },
-            { "ghs", "cedi ghanese" },
-            { "gyd", "dollaro della Guyana" },
-            { "kpw", "won nordcoreano" },
             { "bob", "boliviano" },
-            { "mdl", "leu moldavo" },
-            { "amd", "dram armeno" },
-            { "try", "lira turca" },
-            { "lbp", "lira libanese" },
-            { "jod", "dinaro giordano" },
-            { "hkd", "dollaro di Hong Kong" },
             { "bop", "peso boliviano" },
-            { "eur", "euro" },
-            { "lsl", "loti del Lesotho" },
-            { "cad", "dollaro canadese" },
             { "bov", "mvdol boliviano" },
-            { "eek", "corona dell\u2019Estonia" },
-            { "mur", "rupia mauriziana" },
-            { "rol", "leu della Romania" },
-            { "gip", "sterlina di Gibilterra" },
-            { "ron", "leu rumeno" },
-            { "KRW", "KRW" },
-            { "JPY", "JPY" },
-            { "PLN", "PLN" },
-            { "ngn", "naira nigeriana" },
+            { "brb", "cruzeiro novo brasiliano (1967\u20131986)" },
+            { "brc", "cruzado brasiliano" },
+            { "bre", "cruzeiro brasiliano (1990\u20131993)" },
+            { "brl", "real brasiliano" },
+            { "brn", "cruzado novo brasiliano" },
+            { "brr", "cruzeiro brasiliano" },
+            { "bsd", "dollaro delle Bahamas" },
+            { "btn", "ngultrum bhutanese" },
+            { "buk", "kyat birmano" },
+            { "bwp", "pula del Botswana" },
+            { "byb", "nuovo rublo bielorusso (1994\u20131999)" },
+            { "byn", "rublo bielorusso" },
+            { "byr", "rublo bielorusso (2000\u20132016)" },
+            { "bzd", "dollaro del Belize" },
+            { "cad", "dollaro canadese" },
+            { "cdf", "franco congolese" },
+            { "chf", "franco svizzero" },
+            { "clf", "unidades de fomento chilene" },
+            { "clp", "peso cileno" },
+            { "cnh", "renmimbi cinese offshore" },
+            { "cny", "renminbi cinese" },
+            { "cop", "peso colombiano" },
             { "crc", "col\u00f3n costaricano" },
-            { "pkr", "rupia pakistana" },
-            { "ang", "fiorino delle Antille olandesi" },
-            { "srd", "dollaro del Suriname" },
-            { "ltl", "litas lituano" },
-            { "sar", "riyal saudita" },
-            { "ttd", "dollaro di Trinidad e Tobago" },
-            { "mvr", "rufiyaa delle Maldive" },
-            { "srg", "fiorino del Suriname" },
-            { "ddm", "ostmark della Germania Orientale" },
-            { "inr", "rupia indiana" },
-            { "ltt", "talonas lituani" },
-            { "krw", "won sudcoreano" },
-            { "aoa", "kwanza angolano" },
-            { "jpy", "yen giapponese" },
-            { "pln", "z\u0142oty polacco" },
-            { "sbd", "dollaro delle Isole Salomone" },
             { "csd", "antico dinaro serbo" },
             { "csk", "corona forte cecoslovacca" },
+            { "cuc", "peso cubano convertibile" },
+            { "cup", "peso cubano" },
+            { "cve", "escudo capoverdiano" },
+            { "cyp", "sterlina cipriota" },
+            { "czk", "corona ceca" },
+            { "ddm", "ostmark della Germania Orientale" },
+            { "dem", "marco tedesco" },
+            { "djf", "franco di Gibuti" },
+            { "dkk", "corona danese" },
+            { "dop", "peso dominicano" },
+            { "dzd", "dinaro algerino" },
+            { "ecs", "sucre dell\u2019Ecuador" },
+            { "ecv", "unidad de valor constante (UVC) dell\u2019Ecuador" },
+            { "eek", "corona dell\u2019Estonia" },
+            { "egp", "sterlina egiziana" },
+            { "ern", "nakfa eritreo" },
+            { "esa", "peseta spagnola account" },
+            { "esb", "peseta spagnola account convertibile" },
+            { "esp", "peseta spagnola" },
+            { "etb", "birr etiope" },
+            { "eur", "euro" },
+            { "fim", "markka finlandese" },
+            { "fjd", "dollaro delle Figi" },
+            { "fkp", "sterlina delle Falkland" },
+            { "frf", "franco francese" },
+            { "gbp", "sterlina britannica" },
+            { "gek", "kupon larit georgiano" },
+            { "gel", "lari georgiano" },
+            { "ghc", "cedi del Ghana" },
+            { "ghs", "cedi ghanese" },
+            { "gip", "sterlina di Gibilterra" },
+            { "gmd", "dalasi gambiano" },
+            { "gnf", "franco della Guinea" },
+            { "gns", "syli della Guinea" },
+            { "gqe", "ekwele della Guinea Equatoriale" },
+            { "grd", "dracma greca" },
+            { "gtq", "quetzal guatemalteco" },
+            { "gwe", "escudo della Guinea portoghese" },
+            { "gwp", "peso della Guinea-Bissau" },
+            { "gyd", "dollaro della Guyana" },
+            { "hkd", "dollaro di Hong Kong" },
+            { "hnl", "lempira honduregna" },
+            { "hrd", "dinaro croato" },
+            { "hrk", "kuna croata" },
+            { "htg", "gourde haitiano" },
+            { "huf", "fiorino ungherese" },
+            { "idr", "rupia indonesiana" },
+            { "iep", "sterlina irlandese" },
+            { "ilp", "sterlina israeliana" },
+            { "ils", "nuovo siclo israeliano" },
+            { "inr", "rupia indiana" },
+            { "iqd", "dinaro iracheno" },
+            { "irr", "rial iraniano" },
+            { "isk", "corona islandese" },
+            { "itl", "lira italiana" },
+            { "jmd", "dollaro giamaicano" },
+            { "jod", "dinaro giordano" },
+            { "jpy", "yen giapponese" },
+            { "kes", "scellino keniota" },
+            { "kgs", "som kirghiso" },
+            { "khr", "riel cambogiano" },
+            { "kmf", "franco comoriano" },
+            { "kpw", "won nordcoreano" },
+            { "krw", "won sudcoreano" },
+            { "kwd", "dinaro kuwaitiano" },
+            { "kyd", "dollaro delle Isole Cayman" },
+            { "kzt", "tenge kazako" },
+            { "lak", "kip laotiano" },
+            { "lbp", "lira libanese" },
+            { "lkr", "rupia di Sri Lanka" },
+            { "lrd", "dollaro liberiano" },
+            { "lsl", "loti del Lesotho" },
+            { "ltl", "litas lituano" },
+            { "ltt", "talonas lituani" },
             { "luc", "franco convertibile del Lussemburgo" },
-            { "aok", "kwanza angolano (1977\u20131990)" },
             { "luf", "franco del Lussemburgo" },
-            { "BRL", "BRL" },
+            { "lul", "franco finanziario del Lussemburgo" },
+            { "lvl", "lats lettone" },
+            { "lvr", "rublo lettone" },
+            { "lyd", "dinaro libico" },
+            { "mad", "dirham marocchino" },
+            { "maf", "franco marocchino" },
+            { "mdl", "leu moldavo" },
+            { "mga", "ariary malgascio" },
+            { "mgf", "franco malgascio" },
+            { "mkd", "denar macedone" },
+            { "mlf", "franco di Mali" },
+            { "mmk", "kyat di Myanmar" },
+            { "mnt", "tugrik mongolo" },
+            { "mop", "pataca di Macao" },
+            { "mro", "ouguiya della Mauritania (1973\u20132017)" },
+            { "mru", "ouguiya della Mauritania" },
+            { "mtl", "lira maltese" },
+            { "mtp", "sterlina maltese" },
+            { "mur", "rupia mauriziana" },
+            { "mvr", "rufiyaa delle Maldive" },
+            { "mwk", "kwacha malawiano" },
+            { "mxn", "peso messicano" },
+            { "mxp", "peso messicano d\u2019argento (1861\u20131992)" },
+            { "mxv", "unidad de inversion (UDI) messicana" },
+            { "myr", "ringgit malese" },
+            { "mze", "escudo del Mozambico" },
+            { "mzn", "metical mozambicano" },
+            { "nad", "dollaro namibiano" },
+            { "ngn", "naira nigeriana" },
+            { "nic", "cordoba nicaraguense" },
+            { "nio", "c\u00f3rdoba nicaraguense" },
+            { "nlg", "fiorino olandese" },
+            { "nok", "corona norvegese" },
+            { "npr", "rupia nepalese" },
+            { "nzd", "dollaro neozelandese" },
+            { "omr", "rial omanita" },
+            { "pab", "balboa panamense" },
+            { "pei", "inti peruviano" },
+            { "pen", "sol peruviano" },
+            { "pes", "sol peruviano (1863\u20131965)" },
+            { "pgk", "kina papuana" },
+            { "php", "peso filippino" },
+            { "pkr", "rupia pakistana" },
+            { "pln", "z\u0142oty polacco" },
             { "plz", "z\u0142oty Polacco (1950\u20131995)" },
+            { "pte", "escudo portoghese" },
+            { "pyg", "guaran\u00ed paraguayano" },
+            { "qar", "rial qatariano" },
+            { "rhd", "dollaro della Rhodesia" },
+            { "rol", "leu della Romania" },
+            { "ron", "leu rumeno" },
+            { "rsd", "dinaro serbo" },
+            { "rub", "rublo russo" },
+            { "rur", "rublo della CSI" },
+            { "rwf", "franco ruandese" },
+            { "sar", "riyal saudita" },
+            { "sbd", "dollaro delle Isole Salomone" },
+            { "scr", "rupia delle Seychelles" },
+            { "sdd", "dinaro sudanese" },
+            { "sdg", "sterlina sudanese" },
+            { "sek", "corona svedese" },
+            { "sgd", "dollaro di Singapore" },
+            { "shp", "sterlina di Sant\u2019Elena" },
+            { "sit", "tallero sloveno" },
+            { "skk", "corona slovacca" },
+            { "sll", "leone della Sierra Leone" },
+            { "sos", "scellino somalo" },
+            { "srd", "dollaro del Suriname" },
+            { "srg", "fiorino del Suriname" },
+            { "ssp", "sterlina sud-sudanese" },
+            { "std", "dobra di Sao Tom\u00e9 e Principe (1977\u20132017)" },
+            { "stn", "dobra di Sao Tom\u00e9 e Pr\u00edncipe" },
+            { "sur", "rublo sovietico" },
+            { "svc", "col\u00f3n salvadoregno" },
+            { "syp", "lira siriana" },
+            { "szl", "lilangeni dello Swaziland" },
+            { "thb", "baht thailandese" },
+            { "tjr", "rublo del Tajikistan" },
+            { "tjs", "somoni tagiko" },
+            { "tmm", "manat turkmeno (1993\u20132009)" },
+            { "tmt", "manat turkmeno" },
+            { "tnd", "dinaro tunisino" },
+            { "top", "pa\u02bbanga tongano" },
+            { "tpe", "escudo di Timor" },
+            { "trl", "lira turca (1922\u20132005)" },
+            { "try", "lira turca" },
+            { "ttd", "dollaro di Trinidad e Tobago" },
+            { "twd", "nuovo dollaro taiwanese" },
+            { "tzs", "scellino della Tanzania" },
+            { "uah", "grivnia ucraina" },
+            { "uak", "karbovanetz ucraino" },
+            { "ugs", "scellino ugandese (1966\u20131987)" },
+            { "ugx", "scellino ugandese" },
+            { "usd", "dollaro statunitense" },
+            { "usn", "dollaro statunitense (next day)" },
+            { "uss", "dollaro statunitense (same day)" },
+            { "uyi", "peso uruguaiano in unit\u00e0 indicizzate" },
+            { "uyp", "peso uruguaiano (1975\u20131993)" },
+            { "uyu", "peso uruguayano" },
+            { "uzs", "sum uzbeco" },
+            { "veb", "bolivar venezuelano (1871\u20132008)" },
+            { "vef", "bol\u00edvar venezuelano (2008\u20132018)" },
+            { "ves", "bol\u00edvar venezuelano" },
+            { "vnd", "dong vietnamita" },
+            { "vuv", "vatu di Vanuatu" },
+            { "wst", "tala samoano" },
+            { "xaf", "franco CFA BEAC" },
+            { "xag", "argento" },
+            { "xau", "oro" },
+            { "xba", "unit\u00e0 composita europea" },
+            { "xbb", "unit\u00e0 monetaria europea" },
+            { "xbc", "unit\u00e0 di acconto europea (XBC)" },
+            { "xbd", "unit\u00e0 di acconto europea (XBD)" },
+            { "xcd", "dollaro dei Caraibi orientali" },
+            { "xdr", "diritti speciali di incasso" },
+            { "xfo", "franco oro francese" },
+            { "xfu", "franco UIC francese" },
+            { "xof", "franco CFA BCEAO" },
+            { "xpd", "palladio" },
+            { "xpf", "franco CFP" },
+            { "xpt", "platino" },
+            { "xre", "fondi RINET" },
+            { "xts", "codice di verifica della valuta" },
+            { "xxx", "valuta sconosciuta" },
+            { "ydd", "dinaro dello Yemen" },
+            { "yer", "riyal yemenita" },
+            { "yud", "dinaro forte yugoslavo" },
+            { "yum", "dinaro noviy yugoslavo" },
+            { "yun", "dinaro convertibile yugoslavo" },
+            { "zal", "rand sudafricano (finanziario)" },
+            { "zar", "rand sudafricano" },
+            { "zmk", "kwacha dello Zambia (1968\u20132012)" },
+            { "zmw", "kwacha dello Zambia" },
+            { "zrn", "nuovo zaire dello Zaire" },
+            { "zrz", "zaire dello Zaire" },
+            { "zwd", "dollaro dello Zimbabwe" },
+            { "zwl", "dollaro zimbabwiano (2009)" },
         };
         return data;
     }
