@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -183,11 +183,11 @@ public class CurrencyNames_kea extends OpenListResourceBundle {
             { "djf", "Franku di Djibuti" },
             { "dkk", "Kuroa dinamarkeza" },
             { "dzd", "Dinar arjelinu" },
-            { "egp", "Libra ejipsiu" },
+            { "egp", "Libra ej\u00edpsiu" },
             { "ern", "Nafka di Eritreia" },
-            { "etb", "Bir etiopi" },
+            { "etb", "Bir eti\u00f3piku" },
             { "eur", "Euro" },
-            { "gbp", "Libra britaniku" },
+            { "gbp", "Libra brit\u00e1niku" },
             { "ghc", "Sedi di Gana (1979\u20132007)" },
             { "gmd", "Dalasi" },
             { "gns", "Sili" },
@@ -200,7 +200,7 @@ public class CurrencyNames_kea extends OpenListResourceBundle {
             { "krw", "Won sul-koreanu" },
             { "lrd", "Dola liberianu" },
             { "lsl", "Loti di Lezotu" },
-            { "lyd", "Dinar libiu" },
+            { "lyd", "Dinar l\u00edbiu" },
             { "mad", "Diren marokinu" },
             { "mga", "Ariari di Madagaskar" },
             { "mro", "Ougia (1973\u20132017)" },
@@ -224,7 +224,7 @@ public class CurrencyNames_kea extends OpenListResourceBundle {
             { "sll", "Leone di Sera Leoa" },
             { "sos", "Xelin somalianu" },
             { "std", "Dobra di S\u00e3u Tume i Pr\u00ednsipi (1977\u20132017)" },
-            { "stn", "Dobra di S\u00e3u Tume i Pr\u00ednsipi" },
+            { "stn", "Dobra di San Tume i Pr\u00ednsipi" },
             { "szl", "Lilanjeni" },
             { "thb", "Baht tailandes" },
             { "tnd", "Dinar tunizianu" },
