@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -251,7 +251,7 @@ public class CurrencyNames_ky extends OpenListResourceBundle {
             { "cdf", "\u041a\u043e\u043d\u0433\u043e \u0444\u0440\u0430\u043d\u043a\u044b" },
             { "chf", "\u0448\u0432\u0435\u0439\u0446\u0430\u0440\u0438\u044f \u0444\u0440\u0430\u043d\u043a\u044b" },
             { "clp", "\u0447\u0438\u043b\u0438 \u043f\u0435\u0441\u043e\u0441\u0443" },
-            { "cnh", "CNH" },
+            { "cnh", "\u041a\u044b\u0442\u0430\u0439 \u044e\u0430\u043d\u044b (\u043e\u0444\u0448\u043e\u0440)" },
             { "cny", "\u041a\u044b\u0442\u0430\u0439 \u044e\u0430\u043d\u044b" },
             { "cop", "\u043a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u043f\u0435\u0441\u043e\u0441\u0443" },
             { "crc", "\u043a\u043e\u0441\u0442\u0430-\u0440\u0438\u043a\u0430 \u043a\u043e\u043b\u043e\u043d\u0443" },
@@ -371,7 +371,7 @@ public class CurrencyNames_ky extends OpenListResourceBundle {
             { "uyu", "\u0443\u0440\u0443\u0433\u0432\u0430\u0439 \u043f\u0435\u0441\u043e\u0441\u0443" },
             { "uzs", "\u04e8\u0437\u0431\u0435\u043a\u0441\u0442\u0430\u043d \u0441\u0443\u043c\u0443" },
             { "vef", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0430 \u0431\u043e\u043b\u0438\u0432\u0430\u0440\u044b (2008\u20132018)" },
-            { "ves", "VES" },
+            { "ves", "\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0430 \u0431\u043e\u043b\u0438\u0432\u0430\u0440\u044b" },
             { "vnd", "\u0412\u044c\u0435\u0442\u043d\u0430\u043c \u0434\u043e\u04a3\u0443" },
             { "vuv", "\u0412\u0430\u043d\u0443\u0430\u0442\u0443 \u0432\u0430\u0442\u0443\u0441\u0443" },
             { "wst", "\u0421\u0430\u043c\u043e\u0430 \u0442\u0430\u043b\u0430\u0441\u044b" },
