@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -233,6 +233,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MTL", "MTL" },
             { "MTP", "MTP" },
             { "MUR", "MUR" },
@@ -318,6 +319,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "UZS", "UZS" },
             { "VEB", "VEB" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VNN", "VNN" },
             { "VUV", "VUV" },
             { "WST", "WST" },
@@ -419,9 +421,9 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "cle", "Chileense escudo" },
             { "clf", "Chileense unidades de fomento" },
             { "clp", "Chileense peso" },
-            { "cnh", "Chinese renminbi (offshore)" },
+            { "cnh", "Chinese yuan (offshore)" },
             { "cnx", "dollar van de Chinese Volksbank" },
-            { "cny", "Chinese Yuan" },
+            { "cny", "Chinese yuan" },
             { "cop", "Colombiaanse peso" },
             { "cou", "Unidad de Valor Real" },
             { "crc", "Costa Ricaanse colon" },
@@ -612,9 +614,11 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "uyi", "Uruguayaanse peso en ge\u00efndexeerde eenheden" },
             { "uyp", "Uruguayaanse peso (1975\u20131993)" },
             { "uyu", "Uruguayaanse peso" },
+            { "uyw", "Uruguayaanse nominale salarisindexeenheid" },
             { "uzs", "Oezbeekse sum" },
             { "veb", "Venezolaanse bolivar (1871\u20132008)" },
-            { "vef", "Venezolaanse bolivar" },
+            { "vef", "Venezolaanse bolivar (2008\u20132018)" },
+            { "ves", "Venezolaanse bolivar" },
             { "vnd", "Vietnamese dong" },
             { "vnn", "Vietnamese dong (1978\u20131985)" },
             { "vuv", "Vanuatuaanse vatu" },
