@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,153 +71,25 @@ public class CurrencyNames_so extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "ARS", "ARS" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
             { "BBD", "DBB" },
-            { "BDT", "BDT" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ETB", "ETB" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
             { "MRO", "MRO" },
-            { "MRU", "MRU" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
-            { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
             { "SOS", "S" },
-            { "SRD", "SRD" },
-            { "SSP", "SSP" },
-            { "STN", "STN" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
             { "VEF", "VEF" },
-            { "VES", "VES" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMW", "ZMW" },
             { "aed", "Dirhamka Isutaga Imaaraatka Carabta" },
             { "afn", "Afgan Afgani" },
             { "all", "Lekta Albaniya" },
             { "amd", "Daraamka Armeniya" },
             { "ang", "Galdarka Nadarlaan Antiliyaan" },
             { "aoa", "Kawansada Angola" },
+            { "ara", "Argentine Austral" },
+            { "arl", "Beesada Ley ee Arjentiin (1970\u20131983)" },
+            { "arm", "Beesada Ley ee Arjentiin (1881\u20131970)" },
+            { "arp", "Beesada Ley ee Arjentiin (1883\u20131985)" },
             { "ars", "Beesada Arjentiin" },
             { "aud", "Doolarka Astaraaliya" },
             { "awg", "Foloorinta Aruban" },
             { "azn", "Manaata Asarbeyjan" },
+            { "bad", "Diinaarka BBosnia-Hersogofina 1.00 konfatibal maakta Bosnia-Hersogofina 1 konfatibal maaka Bosnia-Hersogofina (1992\u20131994)" },
             { "bam", "Konfatibal Maakta Bosnia-Hersogofina" },
             { "bbd", "Doolarka Barbaadiyaan" },
             { "bdt", "Taka Bangledesh" },
@@ -227,6 +99,7 @@ public class CurrencyNames_so extends OpenListResourceBundle {
             { "bmd", "Doolarka Barmuuda" },
             { "bnd", "Doolarka Buruney" },
             { "bob", "Bolifiyanada Bolifiya" },
+            { "bol", "Bolifiyaabka Bolifiyaano(1863\u20131963)" },
             { "brl", "Realka Barasil" },
             { "bsd", "Doolarka Bahamaas" },
             { "btn", "Nugultaramta Butan" },
@@ -249,10 +122,12 @@ public class CurrencyNames_so extends OpenListResourceBundle {
             { "dkk", "Koronka Danishka" },
             { "dop", "Beesada Dominiika" },
             { "dzd", "Dinaarka Aljeriya" },
+            { "eek", "Kroonka Estooniya" },
             { "egp", "Bowndka Masar" },
             { "ern", "Nakfada Eritriya" },
             { "etb", "Birta Itoobbiya" },
             { "eur", "Yuuroo" },
+            { "fim", "Markkada Fiinishka ah" },
             { "fjd", "Doolarka Fiji" },
             { "fkp", "Bowndka Faalklaan Aylaanis" },
             { "gbp", "Bowndka Biritishka" },
@@ -269,6 +144,7 @@ public class CurrencyNames_so extends OpenListResourceBundle {
             { "htg", "Goordada Hiyati" },
             { "huf", "Forintiska Hangari" },
             { "idr", "Rubiah Indonesiya" },
+            { "iep", "baawnka Ayrishka" },
             { "ils", "Niyuu Shekelka Israaiil" },
             { "inr", "Rubiga Hindiya" },
             { "iqd", "Dinaarka Ciraaq" },
@@ -290,6 +166,7 @@ public class CurrencyNames_so extends OpenListResourceBundle {
             { "lbp", "Bowndka Lubnaan" },
             { "lkr", "Rubiga Siri lanka" },
             { "lrd", "Doolarka Liberiya" },
+            { "lvr", "Rubalka Latfiya" },
             { "lyd", "Dinaarka Libya" },
             { "mad", "Dirhamka Moroko" },
             { "mdl", "Leeyuuda Moldofa" },
