@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -74,10 +74,15 @@ public class CurrencyNames_to extends OpenListResourceBundle {
             { "AUD", "AUD$" },
             { "NZD", "NZD$" },
             { "TOP", "T$" },
-            { "aud", "Australian Dollar" },
-            { "brl", "BRL" },
+            { "aud", "Tola faka\u02bbaositel\u0113lia" },
+            { "fjd", "Tola fakafisi" },
+            { "nzd", "Tola fakanu\u02bbusila" },
+            { "pgk", "Kina fakapapuaniukini" },
+            { "sbd", "Tola faka\u02bbotusolomone" },
             { "top", "Pa\u02bbanga fakatonga" },
+            { "vuv", "Vatu fakavanuatu" },
             { "wst", "Tala fakaha\u02bbamoa" },
+            { "xpf", "Falaniki fakapasifika" },
             { "xxx", "Pa\u2019anga Ta\u2019e\u2019ilo" },
         };
         return data;
