@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -332,7 +332,8 @@ public class CurrencyNames_ug extends OpenListResourceBundle {
             { "uyu", "\u0626\u06c7\u0631\u06c7\u06af\u06cb\u0627\u064a \u067e\u06d0\u0633\u0648\u0633\u0649" },
             { "uzs", "\u0626\u06c6\u0632\u0628\u06d0\u0643\u0649\u0633\u062a\u0627\u0646 \u0633\u0648\u0645\u0649" },
             { "veb", "\u06cb\u06d0\u0646\u06d0\u0632\u06c7\u0626\u06d0\u0644\u0627 \u0628\u0648\u0644\u0649\u06cb\u0627\u0631\u0649 (1871\u20132008)" },
-            { "vef", "\u06cb\u06d0\u0646\u06d0\u0632\u06c7\u0626\u06d0\u0644\u0627 \u0628\u0648\u0644\u0649\u06cb\u0627\u0631\u0649" },
+            { "vef", "\u06cb\u06d0\u0646\u06d0\u0632\u06c7\u0626\u06d0\u0644\u0627 \u0628\u0648\u0644\u0649\u06cb\u0627\u0631\u0649 (2008\u20132018)" },
+            { "ves", "\u06cb\u06d0\u0646\u06d0\u0632\u06c7\u0626\u06d0\u0644\u0627 \u0628\u0648\u0644\u0649\u06cb\u0627\u0631\u0649" },
             { "vnd", "\u06cb\u0649\u064a\u06d0\u062a\u0646\u0627\u0645 \u062f\u0648\u06ad\u0649" },
             { "vnn", "\u06cb\u0649\u064a\u06d0\u062a\u0646\u0627\u0645 \u062f\u0648\u06ad\u0649 (1978\u20131985)" },
             { "vuv", "\u06cb\u0627\u0646\u06c7\u0626\u0627\u062a\u06c7 \u06cb\u0627\u062a\u06c7\u0633\u0649" },
