@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -559,6 +559,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "TC", "Turks a Caicos" },
             { "yav", "jangben\u0161tina" },
             { "TD", "\u010cad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Francouzsk\u00e1 ji\u017en\u00ed \u00fazem\u00ed" },
             { "ase", "znakov\u00e1 \u0159e\u010d (americk\u00e1)" },
             { "TG", "Togo" },
@@ -739,6 +740,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "scn", "sicil\u0161tina" },
             { "aa", "afar\u0161tina" },
             { "ab", "abch\u00e1z\u0161tina" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak toba" },
             { "ae", "avest\u00e1n\u0161tina" },
             { "af", "afrik\u00e1n\u0161tina" },
@@ -1242,6 +1244,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "inh", "ingu\u0161tina" },
             { "krj", "kinaraj-a" },
             { "kri", "krio" },
+            { "fa_AF", "dar\u00ed" },
             { "krl", "karel\u0161tina" },
             { "efi", "efik\u0161tina" },
             { "tcy", "tulu\u0161tina" },
