@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -100,6 +100,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
         final String metaValue_ban = "Balinesisch";
         final String metaValue_bax = "Bamun";
         final String metaValue_bug = "Buginesisch";
+        final String metaValue_ccp = "Chakma";
         final String metaValue_chr = "Cherokee";
         final String metaValue_cop = "Koptisch";
         final String metaValue_got = "Gotisch";
@@ -130,6 +131,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "Zsye", "Emoji" },
             { "%%NJIVA", "Njiva-Dialekt" },
             { "xmf", "Mingrelisch" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u00c4gyptisch" },
             { "raj", "Rajasthani" },
             { "Phag", "Phags-pa" },
@@ -598,7 +600,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Syrien" },
             { "yao", "Yao" },
-            { "SZ", "Swasiland" },
+            { "SZ", "Eswatini" },
             { "arw", "Arawak" },
             { "arz", "\u00c4gyptisches Arabisch" },
             { "ary", "Marokkanisches Arabisch" },
@@ -611,6 +613,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "TC", "Turks- und Caicosinseln" },
             { "yav", "Yangben" },
             { "TD", "Tschad" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Franz\u00f6sische S\u00fcd- und Antarktisgebiete" },
             { "ase", "Amerikanische Geb\u00e4rdensprache" },
             { "TG", "Togo" },
@@ -693,7 +696,9 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "type.nu.mtei", "Meitei-Mayek-Ziffern" },
             { "wal", "Walamo" },
             { "was", "Washo" },
+            { "XA", "Pseudo-Akzente" },
             { "war", "Waray" },
+            { "XB", "Pseudo-Bidi" },
             { "awa", "Awadhi" },
             { "061", "Polynesien" },
             { "XK", "Kosovo" },
@@ -799,6 +804,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "scn", "Sizilianisch" },
             { "aa", "Afar" },
             { "ab", "Abchasisch" },
+            { "Aran", "Nastaliq" },
             { "bbc", "Batak Toba" },
             { "ae", metaValue_ae },
             { "af", "Afrikaans" },
@@ -888,7 +894,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "type.co.big5han", "Traditionelles Chinesisch - Big5" },
             { "es", "Spanisch" },
             { "et", "Estnisch" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Han mit Bopomofo" },
             { "eu", "Baskisch" },
             { "Buhd", "Buhid" },
             { "Hang", "Hangul" },
@@ -1034,7 +1040,6 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "mdf", "Mokschanisch" },
             { "mde", "Maba" },
             { "dsb", "Niedersorbisch" },
-            { "Armi", "Armi" },
             { "na", "Nauruisch" },
             { "type.co.search", "allgemeine Suche" },
             { "nb", "Norwegisch Bokm\u00e5l" },
@@ -1171,9 +1176,9 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "dyo", "Diola" },
             { "type.nu.jpan", "Japanische Ziffern" },
             { "tr", "T\u00fcrkisch" },
+            { "Cakm", metaValue_ccp },
             { "ts", "Tsonga" },
             { "swb", "Komorisch" },
-            { "Cakm", "Chakma" },
             { "tt", "Tatarisch" },
             { "dyu", "Dyula" },
             { "tw", "Twi" },
@@ -1326,6 +1331,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "inh", "Inguschisch" },
             { "krj", "Kinaray-a" },
             { "kri", "Krio" },
+            { "fa_AF", "Dari" },
             { "krl", "Karelisch" },
             { "efi", "Efik" },
             { "tcy", "Tulu" },
