@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -82,11 +82,13 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "Zsym", "Alamomi" },
             { "fil", "Dan Filifin" },
             { "hmn", "Hmong" },
+            { "Zsye", "Alama ta hoto" },
             { "ccp", "Chakma" },
             { "luy", "Luyia" },
             { "bas", "Basaa" },
             { "es_ES", "Sifaniyanci Turai" },
             { "teo", "Teso" },
+            { "AC", "Tsibirin Ascension" },
             { "AD", "Andora" },
             { "AE", "Ha\u0257a\u0257\u0257iyar Daular Larabawa" },
             { "AF", "Afaganistan" },
@@ -101,14 +103,17 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "Arab", metaValue_ar },
             { "AO", "Angola" },
             { "AQ", "Antatika" },
+            { "Jpan", "Jafanis" },
             { "ar", metaValue_ar },
             { "AR", "Arjantiniya" },
+            { "Hrkt", "kalaman Jafananci" },
             { "AS", "Samowa Ta Amurka" },
             { "as", "Asamisanci" },
             { "AT", "Ostiriya" },
             { "AU", "Ostareliya" },
             { "AW", "Aruba" },
             { "en_US", "Turanci Amirka" },
+            { "AX", "Tsibirai na \u00c5land" },
             { "AZ", "Azarbaijan" },
             { "az", "Azerbaijanci" },
             { "BA", "Bosniya Harzagobina" },
@@ -137,11 +142,15 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "bs", "Bosniyanci" },
             { "xog", "Soga" },
             { "BT", "Butan" },
+            { "BV", "Tsibirin Bouvet" },
             { "BW", "Baswana" },
+            { "Mymr", "\u0198asar Myanmar" },
+            { "type.nu.laoo", "Lambobin Yaren Lao" },
             { "BY", "Belarus" },
             { "seh", "Sena" },
             { "BZ", "Beliz" },
             { "type.ca.persian", "Kalanda Farisa" },
+            { "type.nu.hebr", "Lambobin \u0199irga na Hebrew" },
             { "CA", "Kanada" },
             { "ca", "Kataloniyanci" },
             { "CC", "Tsibirai Cocos (Keeling)" },
@@ -159,6 +168,8 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "CN", "Sin" },
             { "CO", "Kolambiya" },
             { "co", "Corsican" },
+            { "CP", "Tsibirin Clipperton" },
+            { "Orya", "Yaren Odia" },
             { "CR", "Kwasta Rika" },
             { "cs", "Harshen Cak" },
             { "CU", "Kyuba" },
@@ -169,14 +180,20 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "CY", "Sifurus" },
             { "cy", "Kabilar Welsh" },
             { "CZ", "Jamhuriyar Cak" },
+            { "type.nu.ethi", "Lambobin \u0199irga na Ethiopia" },
             { "da", "Danish" },
             { "pt_PT", "Fotugis kasashen Turai" },
             { "DE", "Jamus" },
             { "de", "Jamusanci" },
             { "cgg", "Chiga" },
+            { "DG", "Tsibirn Diego Garcia" },
+            { "type.cf.standard", "Tsarin Kudi Nagartacce" },
+            { "type.nu.deva", "Lambobin Tsarin Rubutu na Devangari" },
             { "DJ", "Jibuti" },
             { "DK", "Danmark" },
+            { "Brai", "Rubutun Makafi" },
             { "DM", "Dominika" },
+            { "type.nu.armnlow", "Kananan Haruffan Armenia" },
             { "DO", "Jamhuriyar Dominika" },
             { "bem", "Bemba" },
             { "es_419", "Sifaniyancin Latin Amirka" },
@@ -184,11 +201,15 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "dz", "Dzongkha" },
             { "bez", "Bena" },
             { "type.ca.chinese", "Kalanda Sin" },
+            { "EA", "Ceuta & Melilla" },
             { "EC", "Ekwador" },
             { "dje", "Zarma" },
+            { "type.nu.grek", "Lambobin \u0199irga na Girka" },
             { "EE", "Estoniya" },
             { "ee", "Ewe" },
+            { "type.lb.normal", "Salo na Raba Layi na Kodayaushe" },
             { "EG", "Misira" },
+            { "EH", "Yammacin Sahara" },
             { "el", "Girkanci" },
             { "en", "Turanci" },
             { "eo", "D\u02bcan/\u02bcYar Kabilar Andalus" },
@@ -201,10 +222,13 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "Hanb", "Han with Bopomofo" },
             { "EU", "Tarayyar Turai" },
             { "eu", "Basque" },
+            { "Hang", "Yaren Hangul" },
             { "type.ca.gregorian", "Gregorian Kalanda" },
             { "EZ", "Sashin Turai" },
             { "shi", "Tachelhit" },
+            { "type.nu.gujr", "Lambobin Yaren Gujarati" },
             { "hsb", "Sorbianci ta Sama" },
+            { "Hani", "Mutanen Han na \u0199asar Sin" },
             { "fa", "Parisanci" },
             { "Hans", "Sau\u0199a\u0199a\u0199\u0199en" },
             { "type.nu.latn", "Lambobi na yammacin" },
@@ -216,7 +240,9 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "FK", "Tsibiran Falkilan" },
             { "FM", "Mikuronesiya" },
             { "yue", "Cantonese" },
+            { "FO", "Tsibirai na Faroe" },
             { "fo", "Faroese" },
+            { "Taml", "Yaren Tamil" },
             { "FR", "Faransa" },
             { "fr", "Faransanci" },
             { "fy", "K\u02bcabilan Firsi" },
@@ -227,6 +253,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "gd", "K\u02bcabilan Scots Gaelic" },
             { "GE", "Jiwarjiya" },
             { "GF", "Gini Ta Faransa" },
+            { "GG", "Yankin Guernsey" },
             { "GH", "Gana" },
             { "GI", "Jibaraltar" },
             { "GL", "Grinlan" },
@@ -237,6 +264,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "GQ", "Gini Ta Ikwaita" },
             { "und", "Harshen da ba a sani ba" },
             { "GR", metaValue_GR },
+            { "GS", "Kudancin Geogia da Kudancin Tsibirin Sandiwic" },
             { "GT", "Gwatamala" },
             { "gu", metaValue_gu },
             { "GU", "Gwam" },
@@ -245,9 +273,12 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "GY", "Guyana" },
             { "ha", "Hausa" },
             { "ckb", "Kurdish na Tsaka" },
+            { "zxx", "Babu abun-ciki na yare" },
             { "he", metaValue_he },
             { "hi", "Harshen Hindi" },
             { "de_AT", "Jamusanci Ostiriya" },
+            { "HK", "Hong Kong Babban Birnin Kasar Chana" },
+            { "HM", "Tsibirin Heard da McDonald" },
             { "HN", "Honduras" },
             { "HR", "Kurowaishiya" },
             { "hr", "Kuroshiyan" },
@@ -259,13 +290,16 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "hu", "Harshen Hungari" },
             { "hy", "Armeniyanci" },
             { "ia", "Yare Tsakanin Kasashe" },
+            { "IC", "Canary Islands" },
             { "ID", "Indunusiya" },
             { "id", "Harshen Indunusiya" },
+            { "type.nu.tibt", "Lambobin yaren Tibet" },
             { "IE", "Ayalan" },
             { "ig", "Inyamuranci" },
             { "naq", "Nama" },
             { "ii", "Sichuan Yi" },
             { "IL", "Izira\u02bcila" },
+            { "IM", "Isle na Mutum" },
             { "IN", "Indiya" },
             { "IO", "Yankin Birtaniya Na Tekun Indiya" },
             { "IQ", "Ira\u0199i" },
@@ -274,7 +308,12 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "is", "Yaren mutanen Iceland" },
             { "IT", "Italiya" },
             { "it", "Italiyanci" },
+            { "Zmth", "Alamar Lissafi" },
+            { "type.nu.thai", "Lambobin yaren Thai" },
+            { "type.nu.beng", "Lambobin Yaren Bangla" },
             { "ja", "Japananci" },
+            { "Mlym", "Yaren Malayalam" },
+            { "JE", "Kasar Jersey" },
             { "type.ca.islamic", "Kalandar Musulunci" },
             { "JM", "Jamaika" },
             { "Beng", "Bangla" },
@@ -282,6 +321,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "JP", "J\u00e0p\u00e2n" },
             { "jv", "Jabananci" },
             { "guz", "Gusii" },
+            { "type.nu.knda", "Lambobin Yaren Kannada" },
             { "de_CH", "Jamusanci Suwizalan" },
             { "smn", "Inari Sami" },
             { "ka", "Jojiyanci" },
@@ -299,6 +339,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "km", "Harshen Kimar" },
             { "KN", "San Kiti Da Nebis" },
             { "kn", "Kannada" },
+            { "Knda", "Yaren Kannada" },
             { "fr_CA", "Farasanci Kanada" },
             { "ko", "Harshen Koreya" },
             { "KP", "Koriya Ta Arewa" },
@@ -317,13 +358,16 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "LB", "Labanan" },
             { "lb", "Luxembourgish" },
             { "LC", "San Lusiya" },
+            { "type.nu.mlym", "Lambobin Yaren Malayalam" },
             { "lg", "Ganda" },
             { "nds", "Low German" },
             { "LI", "Licansitan" },
             { "LK", "Siri Lanka" },
+            { "Tibt", "Yaren Tibet" },
             { "ln", "Lingala" },
             { "fur", "Friulian" },
             { "lo", "Laothian" },
+            { "type.ms.uksystem", "Tsarin Awo na Imperial" },
             { "LR", "Laberiya" },
             { "LS", "Lesoto" },
             { "LT", "Lituweniya" },
@@ -332,9 +376,11 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "lu", "Luba-Katanga" },
             { "LV", "latibiya" },
             { "lv", "Latbiyanci" },
+            { "Kana", "Tsarin Rubutun Katakana" },
             { "LY", "Libiya" },
             { "vun", "Vunjo" },
             { "lag", "Langi" },
+            { "Thaa", "Yaren Thaana" },
             { "MA", "Maroko" },
             { "MC", "Monako" },
             { "MD", "Maldoba" },
@@ -343,6 +389,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "MG", "Madagaskar" },
             { "mg", "Malagasy" },
             { "MH", "Tsibiran Marshal" },
+            { "type.co.ducet", "Tsarin Rabewa na Dan-ma\u0199alu na Asali" },
             { "mi", "Maori" },
             { "MK", "Macedonia ta Arewa" },
             { "mk", "Dan Masedoniya" },
@@ -351,6 +398,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "MM", "Burma, Miyamar" },
             { "MN", "Mangoliya" },
             { "mn", "Mongolian" },
+            { "MO", "Babban Birnin Mulki na Chana" },
             { "MP", "Tsibiran Mariyana Na Arewa" },
             { "MQ", "Martinik" },
             { "MR", "Moritaniya" },
@@ -370,6 +418,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "Armn", "Armeniyawa" },
             { "dsb", "Lower Sorbian" },
             { "NA", "Namibiya" },
+            { "type.co.search", "Bincike na Dalilai-Gamagari" },
             { "202", "Sub-Saharan Africa" },
             { "nb", "Norwegian Bokm\u00e5l" },
             { "type.ca.hebrew", "Kalanda Ibrananci" },
@@ -393,6 +442,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "kab", "Kabyle" },
             { "kam", "Kamba" },
             { "mer", "Meru" },
+            { "type.nu.armn", "Lambobin \u0199irga na Armenia" },
             { "OM", "Oman" },
             { "om", "Oromo" },
             { "or", "Oriyanci" },
@@ -418,16 +468,21 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "ps", "Pashtanci" },
             { "PT", "Portugal" },
             { "pt", "Harshen Fotugis" },
+            { "key.co", "Tsarin Rabewa" },
             { "PW", "Palau" },
+            { "type.nu.greklow", "Kananan Haruffa na Girka" },
             { "PY", "Faragwai" },
             { "Hebr", metaValue_he },
             { "mgh", "Makhuwa-Meetto" },
             { "key.cf", "Yanayin Kudi" },
             { "QA", "Katar" },
             { "key.ca", "Kalanda" },
+            { "Laoo", "Mutanen Laos" },
             { "mgo", "Meta\u02bc" },
             { "type.hc.h23", "Tsarin Awowi 24(0\u201323)" },
             { "type.hc.h24", "Tsarin Awowi 24(1\u201324)" },
+            { "type.nu.mymr", "Lambobin Myanmar" },
+            { "QO", "Bakin Teku" },
             { "qu", "Quechua" },
             { "brx", "Bodo" },
             { "kde", "Makonde" },
@@ -446,6 +501,8 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "RO", "Romaniya" },
             { "ro", "Romaniyanci" },
             { "RS", "Sabiya" },
+            { "type.nu.orya", "Lambobin Yaren Odia" },
+            { "type.nu.hanidec", "Lambobin Gomiya na Yaren \u0199asar Sin" },
             { "RU", "Rasha" },
             { "ru", "Rashanci" },
             { "RW", "Ruwanda" },
@@ -468,10 +525,12 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "SG", "Singapur" },
             { "sg", "Sango" },
             { "SH", "San Helena" },
+            { "type.lb.strict", "Salo na Raba Layi mai Tsauri" },
             { "017", "Afirka ta Tsakiya" },
             { "SI", "Sulobeniya" },
             { "si", "Sinhalanci" },
             { "018", "Kudancin Afirka" },
+            { "SJ", "Svalbard da Jan Mayen" },
             { "019", "nahiyoyin Amurka" },
             { "SK", "Sulobakiya" },
             { "sk", "Basulke" },
@@ -485,9 +544,11 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "so", "Somalianci" },
             { "type.nu.arab", "Lambobi na larabawan a gabas" },
             { "sq", "Albanian" },
+            { "type.nu.taml", "Lambobin \u0199irga na Tamil na Al\u02bcada" },
             { "SR", "Suriname" },
             { "sr", "Sabiyan" },
             { "SS", "Sudan ta kudu" },
+            { "type.cf.account", "Tsarin Kudi na Kididdiga" },
             { "ST", "Sawo Tome Da Paransip" },
             { "st", "Sesotanci" },
             { "su", "Sudananci" },
@@ -496,10 +557,12 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "sw", "Harshen Suwahili" },
             { "SX", "Sint Maarten" },
             { "SY", "Sham, Siriya" },
+            { "type.nu.hantfin", "Lambobin \u0198irgan Kudi na Yaren \u0199asar Sin na Al\u02bcada" },
             { "SZ", "Eswatini" },
             { "TA", "Tritan da Kunha" },
             { "ta", "Tamil" },
             { "asa", "Asu" },
+            { "type.ms.ussystem", "Tsarin Awo na Amurka" },
             { "021", "Arewacin Amurka" },
             { "142", "Asiya" },
             { "TC", "Turkis Da Tsibiran Kaikwas" },
@@ -525,6 +588,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "TO", "Tonga" },
             { "to", "Tongan" },
             { "dyo", "Jola-Fonyi" },
+            { "type.nu.jpan", "Lambobin \u0199irga na Jafananci" },
             { "TR", "Turkiyya" },
             { "tr", "Harshen Turkiyya" },
             { "TT", "Tirinidad Da Tobago" },
@@ -545,8 +609,12 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "035", "Kudu Maso Gabashin Asiya" },
             { "UG", "Yuganda" },
             { "ug", "Ugiranci" },
+            { "Kore", "Koriya" },
+            { "Zyyy", "Gama-gari" },
             { "039", "Kudancin Turai" },
             { "uk", "Harshen Yukuren" },
+            { "Sinh", "Yaren Sinhala" },
+            { "UM", "Rukunin Tsibirin U.S" },
             { "UN", "Majalisar Dinkin Duniya" },
             { "ur", "Urdawa" },
             { "US", "Amurka" },
@@ -560,6 +628,7 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "VA", "Batikan" },
             { "VC", "San Binsan Da Girnadin" },
             { "VE", "Benezuwela" },
+            { "type.ca.roc", "Kalandar kasar Sin" },
             { "VG", "Tsibirin Birjin Na Birtaniya" },
             { "VI", "Tsibiran Birjin Ta Amurka" },
             { "vi", "Harshen Biyetinam" },
@@ -568,8 +637,12 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "VN", "Biyetinam" },
             { "vo", "Volap\u00fck" },
             { "VU", "Banuwatu" },
+            { "rwk", "yaren Rwa" },
+            { "053", "Tsibarai na Austraila da New Zealand da ma\u0199ota" },
+            { "054", "Tsibirai na New Guinea da Fiji da ma\u0199ota" },
             { "WF", "Walis Da Futuna" },
             { "Grek", metaValue_GR },
+            { "057", "Yankin Micronesia" },
             { "jgo", "Ngomba" },
             { "lkt", "Lakota" },
             { "wo", "Wolof" },
@@ -577,8 +650,16 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "zgh", "Standard Moroccan Tamazight" },
             { "ar_001", "Larabci Asali Na Zamani" },
             { "WS", "Samoa" },
+            { "Mong", "Na kasar Mongolia" },
+            { "XA", "Gogewar Kwalwa" },
+            { "XB", "Gano wani abu ta hanyar amfani da fasaha" },
+            { "061", "tsibiri" },
             { "Latn", "Latin" },
+            { "type.nu.hans", "Lambobin \u0199irga na Yaren \u0199asar Sin wanda aka Sau\u0199a\u0199a" },
+            { "type.nu.hant", "Lambobin \u0198irga na Yaren \u0199asar Sin na Al\u02bcada" },
             { "xh", "Bazosa" },
+            { "XK", "Kasar Kosovo" },
+            { "type.nu.romanlow", "Lambobin Kirga Kanana na Rumawa" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "Ba rubutacce ba" },
             { "kkj", "Kako" },
@@ -590,31 +671,48 @@ public class LocaleNames_ha extends OpenListResourceBundle {
             { "YT", "Mayoti" },
             { "vai", "Vai" },
             { "ZA", "Afirka Ta Kudu" },
+            { "type.lb.loose", "Salo na Raba Layi Sakakke" },
             { "kln", "Kalenjin" },
             { "Deva", "Devanagari" },
             { "zh", "Harshen Sinanci" },
+            { "type.nu.geor", "Lambobin \u0199irga na Georgia" },
+            { "Hira", "Tsarin Rubutun Hiragana" },
             { "ZM", "Zambiya" },
             { "Bopo", "Bopomofo" },
+            { "key.lb", "Salo na Raba Layi" },
             { "zu", "Harshen Zulu" },
             { "ZW", "Zimbabuwe" },
             { "ZZ", "Yanki da ba a sani ba" },
             { "Geor", "Georgian" },
+            { "type.ms.metric", "Tsarin Awo na Metric" },
             { "type.ca.iso8601", "Kalanda ISO-8601" },
+            { "type.nu.telu", "Lambobin yaren Telugu" },
+            { "type.nu.jpanfin", "Lambobin \u0199irgan Kudi na Jafananci" },
             { "ebu", "Embu" },
             { "jmc", "Machame" },
             { "zh_Hans", "Sau\u0199a\u0199a\u0199\u0199en Sinanci" },
+            { "type.nu.hansfin", "Lambobin \u0198irgan Kudi na Yaren \u0199asar Sin wanda aka Sau\u0199a\u0199a" },
             { "kok", "Konkani" },
+            { "type.nu.arabext", "Fitattun lambobin lissafi na Larabci" },
             { "nus", "Nuer" },
+            { "type.nu.fullwide", "Lambobi masu Cikakken-Fa\u0257i" },
             { "dav", "Taita" },
             { "lrc", "Northern Luri" },
             { "zh_Hant", "Sinanci na gargajiya" },
+            { "type.nu.khmr", "Lambobin Yaren Khmer" },
             { "mua", "Mundang" },
+            { "type.nu.guru", "Lambobi na Tsarin Rubutun Gurmukhi" },
+            { "Khmr", "Yaren Khmer" },
             { "mul", "Harsuna masu yawa" },
+            { "key.ms", "Tsarin Awo" },
+            { "type.nu.roman", "Lambobin Rumawa" },
             { "sah", "Sakha" },
+            { "type.nu.tamldec", "Lambobin Tamil" },
             { "saq", "Samburu" },
             { "key.nu", "Lambobi" },
             { "Guru", "Gurmukhi" },
             { "ksb", "Shambala" },
+            { "Telu", "Yaren Telugu" },
             { "ksf", "Bafia" },
         };
         return data;
