@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -92,6 +92,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
         final String metaValue_te = "\u0924\u0947\u0932\u0941\u0917\u0942";
         final String metaValue_th = "\u0925\u093e\u0908";
         final String metaValue_bug = "\u092c\u0917\u093f\u0928\u0940\u0938";
+        final String metaValue_ccp = "\u091a\u0915\u092e\u093e";
         final String metaValue_chr = "\u091a\u0947\u0930\u094b\u0915\u0940";
         final String metaValue_cop = "\u0915\u0949\u092a\u094d\u091f\u093f\u0915";
         final String metaValue_peo = "\u092a\u0941\u0930\u093e\u0928\u0940 \u092b\u093e\u0930\u0938\u0940";
@@ -107,6 +108,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "Tagb", "\u0924\u0917\u092c\u0928\u094d\u0935\u093e" },
             { "Zsye", "\u0908\u092e\u094b\u091c\u0940" },
             { "%%NJIVA", "\u091c\u0940\u0935\u093e \u092c\u094b\u0932\u0940" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u092a\u094d\u0930\u093e\u091a\u0940\u0928 \u092e\u093f\u0938\u094d\u0930\u0940" },
             { "raj", "\u0930\u093e\u091c\u0938\u094d\u0925\u093e\u0928\u0940" },
             { "Phag", "\u092b\u093e\u0917\u094d\u0938-\u092a\u093e" },
@@ -301,7 +303,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "HU", "\u0939\u0902\u0917\u0930\u0940" },
             { "tmh", "\u0924\u093e\u092e\u093e\u0936\u0947\u0915" },
             { "IC", "\u0915\u0948\u0928\u0947\u0930\u0940 \u0926\u094d\u0935\u0940\u092a\u0938\u092e\u0942\u0939" },
-            { "nan", "nan" },
+            { "nan", "\u092e\u093f\u0928 \u0928\u093e\u0928" },
             { "peo", metaValue_peo },
             { "ID", "\u0907\u0902\u0921\u094b\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "IE", "\u0906\u092f\u0930\u0932\u0948\u0902\u0921" },
@@ -389,7 +391,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "MH", "\u092e\u093e\u0930\u094d\u0936\u0932 \u0926\u094d\u0935\u0940\u092a\u0938\u092e\u0942\u0939" },
             { "ale", "\u0905\u0932\u0947\u0909\u0924" },
             { "type.nu.vaii", "\u0935\u093e\u0908 \u0905\u0902\u0915" },
-            { "MK", "\u092e\u0915\u0926\u0942\u0928\u093f\u092f\u093e" },
+            { "MK", "\u0909\u0924\u094d\u0924\u0930\u0940 \u092e\u0915\u0926\u0942\u0928\u093f\u092f\u093e" },
             { "ML", "\u092e\u093e\u0932\u0940" },
             { "MM", "\u092e\u094d\u092f\u093e\u0902\u092e\u093e\u0930 (\u092c\u0930\u094d\u092e\u093e)" },
             { "MN", "\u092e\u0902\u0917\u094b\u0932\u093f\u092f\u093e" },
@@ -530,6 +532,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "TC", "\u0924\u0941\u0930\u094d\u0915 \u0914\u0930 \u0915\u0948\u0915\u094b\u091c\u093c \u0926\u094d\u0935\u0940\u092a\u0938\u092e\u0942\u0939" },
             { "yav", "\u092f\u093e\u0902\u0917\u092c\u0947\u0928" },
             { "TD", "\u091a\u093e\u0921" },
+            { "Qaag", "\u091c\u093c\u094c\u091c\u0940" },
             { "TF", "\u092b\u093c\u094d\u0930\u093e\u0902\u0938\u0940\u0938\u0940 \u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
             { "TG", "\u091f\u094b\u0917\u094b" },
             { "TH", "\u0925\u093e\u0908\u0932\u0948\u0902\u0921" },
@@ -598,7 +601,9 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "WS", "\u0938\u092e\u094b\u0906" },
             { "wal", "\u0935\u0932\u093e\u092e\u094b" },
             { "was", "\u0935\u093e\u0936\u094b" },
+            { "XA", "\u0938\u0942\u0921\u094b-\u090f\u0915\u094d\u0938\u0947\u0902\u091f" },
             { "war", "\u0935\u093e\u0930\u0948" },
+            { "XB", "\u0938\u0942\u0921\u094b-\u092c\u093e\u092f\u0921\u093e\u092f\u0930\u0947\u0915\u094d\u0936\u0928\u0932" },
             { "awa", "\u0905\u0935\u0927\u0940" },
             { "061", "\u092a\u094b\u0932\u093f\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "XK", "\u0915\u094b\u0938\u094b\u0935\u094b" },
@@ -687,6 +692,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "scn", "\u0938\u093f\u0938\u093f\u0932\u093f\u092f\u0928" },
             { "aa", "\u0905\u092b\u093c\u093e\u0930" },
             { "ab", "\u0905\u092c\u094d\u0916\u093c\u093e\u091c\u093c\u093f\u092f\u0928" },
+            { "Aran", "\u0928\u0938\u094d\u0924\u093e\u0932\u0940\u0915\u093c" },
             { "ae", "\u0905\u0935\u0938\u094d\u0924\u093e\u0908" },
             { "af", "\u0905\u092b\u093c\u094d\u0930\u0940\u0915\u0940" },
             { "ak", "\u0905\u0915\u0928" },
@@ -1015,9 +1021,9 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "dyo", "\u091c\u094b\u0932\u093e-\u092b\u094b\u0902\u0908" },
             { "type.nu.jpan", "\u091c\u093e\u092a\u093e\u0928\u0940 \u0938\u0902\u0916\u094d\u092f\u093e\u090f\u0901" },
             { "tr", metaValue_TR },
+            { "Cakm", metaValue_ccp },
             { "ts", "\u0938\u094b\u0902\u0917\u093e" },
             { "swb", "\u0915\u094b\u092e\u094b\u0930\u093f\u092f\u0928" },
-            { "Cakm", "\u091a\u0915\u092e\u093e" },
             { "tt", "\u0924\u093e\u0924\u093e\u0930" },
             { "dyu", "\u0921\u094d\u092f\u0941\u0932\u093e" },
             { "tw", "\u091f\u094d\u0935\u0940" },
@@ -1139,6 +1145,7 @@ public class LocaleNames_hi extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0924\u092e\u093f\u0932 \u0905\u0902\u0915" },
             { "krc", "\u0915\u0930\u093e\u091a\u092f-\u092c\u0932\u094d\u0915\u093e\u0930" },
             { "inh", "\u0907\u0902\u0917\u0941\u0936" },
+            { "fa_AF", "\u0926\u093e\u0930\u0940" },
             { "krl", "\u0915\u0930\u0947\u0932\u093f\u092f\u0928" },
             { "efi", "\u090f\u092b\u093f\u0915" },
             { "key.nu", "\u0938\u0902\u0916\u094d\u092f\u093e\u090f\u0901" },
