@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -142,12 +142,12 @@ public class LocaleNames_mt extends OpenListResourceBundle {
             { "CD", "ir-Repubblika Demokratika tal-Kongo" },
             { "CF", "ir-Repubblika \u010aentru-Afrikana" },
             { "CG", "il-Kongo - Brazzaville" },
-            { "CH", "\u017bvizzera" },
+            { "CH", "l-I\u017cvizzera" },
             { "CI", "il-Kosta tal-Avorju" },
             { "CK", "G\u017cejjer Cook" },
             { "CL", "i\u010b-\u010aili" },
             { "CM", "il-Kamerun" },
-            { "CN", "CN" },
+            { "CN", "i\u010b-\u010aina" },
             { "CO", "il-Kolombja" },
             { "CP", "il-G\u017cira Clipperton" },
             { "CR", "il-Costa Rica" },
@@ -319,7 +319,7 @@ public class LocaleNames_mt extends OpenListResourceBundle {
             { "MG", "Madagascar" },
             { "MH", "G\u017cejjer Marshall" },
             { "ale", "Aleut" },
-            { "MK", "l-Eks-Repubblika Jugoslava tal-Ma\u010bedonia" },
+            { "MK", "il-Ma\u010bedonja ta\u2019 Fuq" },
             { "ML", "il-Mali" },
             { "MM", "il-Myanmar/Burma" },
             { "MN", "il-Mongolja" },
@@ -501,7 +501,7 @@ public class LocaleNames_mt extends OpenListResourceBundle {
             { "war", "Waray" },
             { "awa", "Awadhi" },
             { "061", "Polinesja" },
-            { "XK", "Kosovo" },
+            { "XK", "il-Kosovo" },
             { "Zxxx", "Mhux Miktub" },
             { "YE", "il-Jemen" },
             { "nqo", "N\u2019Ko" },
