@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -542,7 +542,9 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "wae", "\u101d\u1031\u102b\u101c\u103a\u1006\u102c" },
             { "WS", "\u1006\u1019\u102d\u102f\u1038\u1021\u102c\u1038" },
             { "wal", "\u101d\u102d\u102f\u101c\u1000\u103a\u1010\u102c" },
+            { "XA", "\u1014\u102d\u102f\u1004\u103a\u1004\u1036\u1001\u103c\u102c\u1038\u101e\u1036" },
             { "war", "\u101d\u102b\u101b\u1031\u1038" },
+            { "XB", "\u1005\u102c\u1015\u103c\u1031\u102c\u1004\u103a\u1038\u1015\u103c\u1014\u103a" },
             { "awa", "\u1021\u102c\u101d\u102b\u1012\u102e" },
             { "061", "\u1015\u102d\u102f\u101c\u102e\u1014\u102e\u101b\u103e\u102c\u1038" },
             { "XK", "\u1000\u102d\u102f\u1006\u102d\u102f\u1017\u102d\u102f" },
@@ -962,6 +964,7 @@ public class LocaleNames_my extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u1010\u1019\u102e\u1038\u101c\u103a \u1002\u100f\u1014\u103a\u1038\u1001\u103c\u1031" },
             { "krc", "\u1000\u101b\u102c\u1001\u103b\u1031\u1038-\u1018\u102c\u1000\u102c" },
             { "inh", "\u1021\u1004\u103a\u1002\u102f\u101b\u103e\u103a" },
+            { "fa_AF", "\u1012\u102b\u101b\u102e" },
             { "krl", "\u1000\u102c\u101b\u102e\u101c\u102e\u101a\u1014\u103a" },
             { "efi", "\u1021\u102c\u1016\u102d\u1001\u103a" },
             { "key.nu", "\u1000\u102d\u1014\u103a\u1038\u1002\u100f\u1014\u103a\u1038" },
