@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -89,7 +89,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "raj", "Ti\u1ebfng Rajasthani" },
             { "Phag", "Ch\u1eef Phags-pa" },
             { "tem", "Ti\u1ebfng Timne" },
-            { "Medf", "Medf" },
             { "type.nu.sind", "Ch\u1eef s\u1ed1 Sind" },
             { "teo", "Ti\u1ebfng Teso" },
             { "rap", "Ti\u1ebfng Rapanui" },
@@ -97,7 +96,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "AC", "\u0110\u1ea3o Ascension" },
             { "rar", "Ti\u1ebfng Rarotongan" },
             { "tet", "Ti\u1ebfng Tetum" },
-            { "%%BARLA", "BARLA" },
             { "type.nu.sinh", "Ch\u1eef s\u1ed1 Sinh" },
             { "AD", "Andorra" },
             { "AE", "C\u00e1c Ti\u1ec3u V\u01b0\u01a1ng qu\u1ed1c \u1ea2 R\u1eadp Th\u1ed1ng nh\u1ea5t" },
@@ -132,7 +130,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kum", "Ti\u1ebfng Kumyk" },
             { "BE", "B\u1ec9" },
             { "gmh", "Ti\u1ebfng Th\u01b0\u1ee3ng Gi\u00e9c-man Trung c\u1ed5" },
-            { "Sogo", "Sogo" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgaria" },
             { "BH", "Bahrain" },
@@ -155,7 +152,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "BZ", "Belize" },
             { "Visp", "Ti\u1ebfng n\u00f3i Nh\u00ecn th\u1ea5y \u0111\u01b0\u1ee3c" },
             { "type.ca.persian", "L\u1ecbch Ba T\u01b0" },
-            { "%%CREISS", "CREISS" },
             { "type.nu.hebr", "Ch\u1eef s\u1ed1 Do Th\u00e1i" },
             { "CA", "Canada" },
             { "CC", "Qu\u1ea7n \u0111\u1ea3o Cocos (Keeling)" },
@@ -181,10 +177,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.bali", "Ch\u1eef s\u1ed1 Bali" },
             { "CZ", "S\u00e9c" },
             { "eka", "Ti\u1ebfng Ekajuk" },
-            { "Ahom", "Ahom" },
-            { "Pauc", "Pauc" },
             { "%%RIGIK", "Ti\u1ebfng Volap\u00fck C\u1ed5 \u0111i\u1ec3n" },
-            { "Sogd", "Sogd" },
             { "DE", "\u0110\u1ee9c" },
             { "goh", "Ti\u1ebfng Th\u01b0\u1ee3ng Gi\u00e9c-man c\u1ed5" },
             { "ace", "Ti\u1ebfng Achinese" },
@@ -250,7 +243,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "Taml", "Ch\u1eef Tamil" },
             { "FR", "Ph\u00e1p" },
             { "Kpel", "Ch\u1eef Kpelle" },
-            { "%%SIMPLE", "SIMPLE" },
             { "tkl", "Ti\u1ebfng Tokelau" },
             { "grb", "Ti\u1ebfng Grebo" },
             { "root", "Ti\u1ebfng Root" },
@@ -262,7 +254,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "GB", "V\u01b0\u01a1ng qu\u1ed1c Anh" },
             { "pcm", "Ti\u1ebfng Nigeria Pidgin" },
             { "GD", "Grenada" },
-            { "GE", "Gruzia" },
+            { "GE", "Georgia" },
             { "GF", "Guiana thu\u1ed9c Ph\u00e1p" },
             { "GG", "Guernsey" },
             { "GH", "Ghana" },
@@ -288,7 +280,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "ckb", "Ti\u1ebfng Kurd Mi\u1ec1n Trung" },
             { "zxx", "Kh\u00f4ng c\u00f3 n\u1ed9i dung ng\u00f4n ng\u1eef" },
             { "Jurc", "Ch\u1eef Jurchen" },
-            { "%%VIVARAUP", "VIVARAUP" },
             { "HK", "H\u1ed3ng K\u00f4ng, Trung Qu\u1ed1c" },
             { "Vaii", "Ch\u1eef Vai" },
             { "HM", "Qu\u1ea7n \u0111\u1ea3o Heard v\u00e0 McDonald" },
@@ -304,7 +295,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "nan", "Ti\u1ebfng M\u00e2n Nam" },
             { "ID", "Indonesia" },
             { "peo", "Ti\u1ebfng Ba T\u01b0 c\u1ed5" },
-            { "Adlm", "Adlm" },
             { "type.nu.kali", "Ch\u1eef s\u1ed1 Kayah Li" },
             { "IE", "Ireland" },
             { "nap", "Ti\u1ebfng Napoli" },
@@ -331,20 +321,17 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "JE", "Jersey" },
             { "type.ca.islamic", "L\u1ecbch H\u1ed3i Gi\u00e1o" },
             { "JM", "Jamaica" },
-            { "Beng", "Ch\u1eef Bangladesh" },
-            { "%%EKAVSK", "EKAVSK" },
+            { "Beng", "Ch\u1eef Bangla" },
             { "JO", "Jordan" },
             { "gur", "Ti\u1ebfng Frafra" },
             { "JP", "Nh\u1eadt B\u1ea3n" },
             { "%%1606NICT", "Ti\u1ebfng Ph\u00e1p t\u1eeb Cu\u1ed1i th\u1eddi Trung c\u1ed5 \u0111\u1ebfn 1606" },
             { "ain", "Ti\u1ebfng Ainu" },
-            { "%%KOCIEWIE", "KOCIEWIE" },
             { "Mend", "Ch\u1eef Mende" },
             { "guz", "Ti\u1ebfng Gusii" },
             { "tog", "Ti\u1ebfng Nyasa Tonga" },
             { "type.nu.knda", "Ch\u1eef s\u1ed1 Kannada" },
             { "Kali", "Ch\u1eef Kayah Li" },
-            { "Sidd", "Sidd" },
             { "de_CH", "Ti\u1ebfng Th\u01b0\u1ee3ng Gi\u00e9c-man (Th\u1ee5y S\u0129)" },
             { "type.co.phonetic", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo ng\u1eef \u00e2m" },
             { "izh", "Ti\u1ebfng Ingria" },
@@ -377,7 +364,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "LK", "Sri Lanka" },
             { "akk", "Ti\u1ebfng Akkadia" },
             { "cop", "Ti\u1ebfng Coptic" },
-            { "Hmnp", "Hmnp" },
             { "LR", "Liberia" },
             { "esu", "Ti\u1ebfng Yupik Mi\u1ec1n Trung" },
             { "LS", "Lesotho" },
@@ -392,7 +378,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "vun", "Ti\u1ebfng Vunjo" },
             { "akz", "Ti\u1ebfng Alabama" },
             { "lah", "Ti\u1ebfng Lahnda" },
-            { "Mahj", "Mahj" },
             { "lag", "Ti\u1ebfng Langi" },
             { "Thaa", "Ch\u1eef Thaana" },
             { "MA", "Ma-r\u1ed1c" },
@@ -432,7 +417,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "MZ", "Mozambique" },
             { "Phli", "Ch\u1eef Pahlavi V\u0103n bia" },
             { "NA", "Namibia" },
-            { "%%ARANES", "ARANES" },
             { "202", "Ch\u00e2u Phi h\u1ea1 Sahara" },
             { "type.ca.hebrew", "L\u1ecbch Do Th\u00e1i" },
             { "type.co.dictionary", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo t\u1eeb \u0111i\u1ec3n" },
@@ -456,12 +440,10 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "tsi", "Ti\u1ebfng Tsimshian" },
             { "NZ", "New Zealand" },
             { "Merc", "Ch\u1eef Meroitic N\u00e9t th\u1ea3o" },
-            { "%%COLB1945", "COLB1945" },
             { "rom", "Ti\u1ebfng Romany" },
             { "Mero", "Ch\u1eef Meroitic" },
             { "crh", "Ti\u1ebfng Th\u1ed5 Nh\u0129 K\u1ef3 Crimean" },
             { "ang", "Ti\u1ebfng Anh c\u1ed5" },
-            { "%%GRMISTR", "GRMISTR" },
             { "OM", "Oman" },
             { "anp", "Ti\u1ebfng Angika" },
             { "crs", "Ti\u1ebfng Ph\u00e1p Seselwa Creole" },
@@ -477,7 +459,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "PG", "Papua New Guinea" },
             { "PH", "Philippines" },
             { "PK", "Pakistan" },
-            { "%%NICARD", "NICARD" },
             { "PL", "Ba Lan" },
             { "ewo", "Ti\u1ebfng Ewondo" },
             { "PM", "Saint Pierre v\u00e0 Miquelon" },
@@ -504,8 +485,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.takr", "Ch\u1eef s\u1ed1 Takri" },
             { "tvl", "Ti\u1ebfng Tuvalu" },
             { "Tavt", "Ch\u1eef Th\u00e1i Vi\u1ec7t" },
-            { "%%SOTAV", "SOTAV" },
-            { "Maka", "Maka" },
             { "001", "Th\u1ebf gi\u1edbi" },
             { "002", "Ch\u00e2u Phi" },
             { "njo", "Ti\u1ebfng Ao Naga" },
@@ -515,7 +494,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "jbo", "Ti\u1ebfng Lojban" },
             { "Rjng", "Ch\u1eef Rejang" },
             { "009", "Ch\u00e2u \u0110\u1ea1i D\u01b0\u01a1ng" },
-            { "Elym", "Elym" },
             { "RO", "Romania" },
             { "RS", "Serbia" },
             { "Mroo", "Ch\u1eef Mro" },
@@ -580,7 +558,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "TC", "Qu\u1ea7n \u0111\u1ea3o Turks v\u00e0 Caicos" },
             { "yav", "Ti\u1ebfng Yangben" },
             { "TD", "Chad" },
-            { "Qaag", "Qaag" },
+            { "Qaag", "Ch\u1eef Zawgyi" },
             { "TF", "L\u00e3nh th\u1ed5 ph\u00eda Nam Thu\u1ed9c Ph\u00e1p" },
             { "ase", "Ng\u00f4n ng\u1eef K\u00fd hi\u1ec7u M\u1ef9" },
             { "TG", "Togo" },
@@ -624,7 +602,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "US", "Hoa K\u1ef3" },
             { "haw", "Ti\u1ebfng Hawaii" },
             { "%%1959ACAD", "H\u00e0n l\u00e2m" },
-            { "%%IVANCHOV", "IVANCHOV" },
             { "type.co.gb2312han", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo ti\u1ebfng Trung gi\u1ea3n th\u1ec3 - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "Ti\u1ebfng Prussia" },
@@ -635,24 +612,20 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "VA", "Th\u00e0nh Vatican" },
             { "pro", "Ti\u1ebfng Proven\u00e7al c\u1ed5" },
             { "VC", "St. Vincent v\u00e0 Grenadines" },
-            { "%%HSISTEMO", "HSISTEMO" },
             { "VE", "Venezuela" },
             { "VG", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c Anh" },
             { "VI", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c M\u1ef9" },
-            { "%%LEMOSIN", "LEMOSIN" },
-            { "Soyo", "Soyo" },
             { "VN", "Vi\u1ec7t Nam" },
             { "VU", "Vanuatu" },
-            { "Marc", "Marc" },
             { "nog", "Ti\u1ebfng Nogai" },
             { "rwk", "Ti\u1ebfng Rwa" },
             { "non", "Ti\u1ebfng Na Uy c\u1ed5" },
-            { "053", "\u00dac v\u00e0 New Zealand" },
+            { "053", "Australasia" },
             { "%%AREVMDA", "Ti\u1ebfng Armenia Mi\u1ec1n T\u00e2y" },
             { "054", "Melanesia" },
             { "WF", "Wallis v\u00e0 Futuna" },
             { "type.co.traditional", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp truy\u1ec1n th\u1ed1ng" },
-            { "057", "V\u00f9ng Micronesian" },
+            { "057", "V\u00f9ng Micronesia" },
             { "jgo", "Ti\u1ebfng Ngomba" },
             { "lkt", "Ti\u1ebfng Lakota" },
             { "type.nu.finance", "Ch\u1eef s\u1ed1 d\u00f9ng trong t\u00e0i ch\u00ednh" },
@@ -664,9 +637,9 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.mtei", "Ch\u1eef s\u1ed1 Meetei Mayek" },
             { "wal", "Ti\u1ebfng Walamo" },
             { "was", "Ti\u1ebfng Washo" },
-            { "XA", "XA" },
+            { "XA", "Pseudo-Accents" },
             { "war", "Ti\u1ebfng Waray" },
-            { "XB", "XB" },
+            { "XB", "Pseudo-Bidi" },
             { "awa", "Ti\u1ebfng Awadhi" },
             { "061", "Polynesia" },
             { "%%KSCOR", "Ph\u00e9p ch\u00ednh t\u1ea3 Chu\u1ea9n" },
@@ -681,20 +654,17 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "YE", "Yemen" },
             { "nqo", "Ti\u1ebfng N\u2019Ko" },
             { "type.co.standard", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp chu\u1ea9n" },
-            { "Zanb", "Zanb" },
             { "fan", "Ti\u1ebfng Fang" },
-            { "%%BALANKA", "BALANKA" },
             { "%%ROZAJ", "Ti\u1ebfng Resian" },
             { "fat", "Ti\u1ebfng Fanti" },
             { "Sgnw", "Ch\u1eef vi\u1ebft K\u00fd hi\u1ec7u" },
             { "YT", "Mayotte" },
             { "type.nu.cham", "Ch\u1eef s\u1ed1 Ch\u0103m" },
-            { "%%NEWFOUND", "NEWFOUND" },
             { "ZA", "Nam Phi" },
             { "type.nu.sund", "Ch\u1eef s\u1ed1 Sudan" },
             { "type.lb.loose", "Ki\u1ec3u xu\u1ed1ng d\u00f2ng tho\u00e1ng" },
             { "Deva", "Ch\u1eef Devanagari" },
-            { "type.nu.geor", "Ch\u1eef s\u1ed1 Gruzia" },
+            { "type.nu.geor", "Ch\u1eef s\u1ed1 Georgia" },
             { "type.co.zhuyin", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp Zhuyin" },
             { "Hira", "Ch\u1eef Hiragana" },
             { "ZM", "Zambia" },
@@ -709,10 +679,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.telu", "Ch\u1eef s\u1ed1 Telugu" },
             { "lou", "Ti\u1ebfng Creole Louisiana" },
             { "loz", "Ti\u1ebfng Lozi" },
-            { "%%FONKIRSH", "FONKIRSH" },
             { "Nkgb", "Ch\u1eef Naxi Geba" },
-            { "%%ASANTE", "ASANTE" },
-            { "%%AUVERN", "AUVERN" },
             { "jmc", "Ti\u1ebfng Machame" },
             { "hif", "Ti\u1ebfng Fiji Hindi" },
             { "type.nu.hansfin", "Ch\u1eef s\u1ed1 d\u00f9ng trong t\u00e0i ch\u00ednh c\u1ee7a ti\u1ebfng Trung gi\u1ea3n th\u1ec3" },
@@ -731,7 +698,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "nwc", "Ti\u1ebfng Newari c\u1ed5" },
             { "udm", "Ti\u1ebfng Udmurt" },
             { "Khmr", "Ch\u1eef Kh\u01a1-me" },
-            { "%%FONNAPA", "FONNAPA" },
             { "type.ca.islamic-rgsa", "L\u1ecbch H\u1ed3i Gi\u00e1o - \u1ea2 R\u1eadp X\u00ea-\u00fat" },
             { "Limb", "Ch\u1eef Limbu" },
             { "sad", "Ti\u1ebfng Sandawe" },
@@ -739,7 +705,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sah", "Ti\u1ebfng Sakha" },
             { "type.nu.shrd", "Ch\u1eef s\u1ed1 Sharada" },
             { "sam", "Ti\u1ebfng Samaritan Aramaic" },
-            { "Aghb", "Aghb" },
             { "%%SCOUSE", "Ph\u01b0\u01a1ng ng\u1eef Liverpool" },
             { "saq", "Ti\u1ebfng Samburu" },
             { "sas", "Ti\u1ebfng Sasak" },
@@ -756,7 +721,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.d0.fwidth", "\u0110\u1ed9 r\u1ed9ng t\u1ed1i \u0111a" },
             { "sbp", "Ti\u1ebfng Sangu" },
             { "lui", "Ti\u1ebfng Luiseno" },
-            { "%%GRITAL", "GRITAL" },
             { "nyn", "Ti\u1ebfng Nyankole" },
             { "nym", "Ti\u1ebfng Nyamwezi" },
             { "lun", "Ti\u1ebfng Lunda" },
@@ -775,7 +739,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "bar", "Ti\u1ebfng Bavaria" },
             { "bas", "Ti\u1ebfng Basaa" },
             { "bax", "Ti\u1ebfng Bamun" },
-            { "%%ABL1943", "ABL1943" },
             { "jrb", "Ti\u1ebfng Judeo-\u1ea2 R\u1eadp" },
             { "es_ES", "Ti\u1ebfng T\u00e2y Ban Nha (Ch\u00e2u \u00c2u)" },
             { "nzi", "Ti\u1ebfng Nzima" },
@@ -783,6 +746,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "scn", "Ti\u1ebfng Sicilia" },
             { "aa", "Ti\u1ebfng Afar" },
             { "ab", "Ti\u1ebfng Abkhazia" },
+            { "Aran", "Ch\u1eef Nastaliq" },
             { "bbc", "Ti\u1ebfng Batak Toba" },
             { "ae", "Ti\u1ebfng Avestan" },
             { "af", "Ti\u1ebfng Afrikaans" },
@@ -803,11 +767,8 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sdh", "Ti\u1ebfng Kurd Mi\u1ec1n Nam" },
             { "ay", "Ti\u1ebfng Aymara" },
             { "az", "Ti\u1ebfng Azerbaijan" },
-            { "Rohg", "Rohg" },
             { "Khoj", "Ch\u1eef Khojki" },
-            { "%%CISAUP", "CISAUP" },
             { "%%OSOJS", "Ph\u01b0\u01a1ng ng\u1eef Oseacco/Osojane" },
-            { "%%UNIFON", "UNIFON" },
             { "ba", "Ti\u1ebfng Bashkir" },
             { "type.co.unihan", "Tr\u00ecnh t\u1ef1 s\u1eafp x\u1ebfp theo b\u1ed9-n\u00e9t" },
             { "be", "Ti\u1ebfng Belarus" },
@@ -820,7 +781,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "dgr", "Ti\u1ebfng Dogrib" },
             { "br", "Ti\u1ebfng Breton" },
             { "bs", "Ti\u1ebfng Bosnia" },
-            { "Bhks", "Bhks" },
             { "see", "Ti\u1ebfng Seneca" },
             { "Mymr", "Ch\u1eef Myanmar" },
             { "type.nu.laoo", "Ch\u1eef s\u1ed1 L\u00e0o" },
@@ -872,10 +832,10 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.co.big5han", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo ti\u1ebfng Trung ph\u1ed3n th\u1ec3 - Big5" },
             { "es", "Ti\u1ebfng T\u00e2y Ban Nha" },
             { "et", "Ti\u1ebfng Estonia" },
-            { "Hanb", "Ch\u1eef Hanb" },
+            { "Hanb", "Ch\u1eef H\u00e1n c\u00f3 ch\u00fa \u00e2m" },
             { "eu", "Ti\u1ebfng Basque" },
             { "Buhd", "Ch\u1eef Buhid" },
-            { "Hang", "Ch\u1eef Hangul" },
+            { "Hang", "Ch\u1eef H\u00e0n" },
             { "Samr", "Ch\u1eef Samaritan" },
             { "shi", "Ti\u1ebfng Tachelhit" },
             { "hsb", "Ti\u1ebfng Th\u01b0\u1ee3ng Sorbia" },
@@ -898,15 +858,11 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.m0.bgn", "Chuy\u1ec3n t\u1ef1 US BGN" },
             { "umb", "Ti\u1ebfng Umbundu" },
             { "fr", "Ti\u1ebfng Ph\u00e1p" },
-            { "%%AKUAPEM", "AKUAPEM" },
             { "sid", "Ti\u1ebfng Sidamo" },
             { "fy", "Ti\u1ebfng Frisia" },
             { "ga", "Ti\u1ebfng Ireland" },
-            { "Wcho", "Wcho" },
             { "gd", "Ti\u1ebfng Gael Scotland" },
-            { "Gong", "Gong" },
             { "gl", "Ti\u1ebfng Galician" },
-            { "Gonm", "Gonm" },
             { "gn", "Ti\u1ebfng Guarani" },
             { "bho", "Ti\u1ebfng Bhojpuri" },
             { "und", "Ng\u00f4n ng\u1eef kh\u00f4ng x\u00e1c \u0111\u1ecbnh" },
@@ -934,11 +890,9 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "id", "Ti\u1ebfng Indonesia" },
             { "type.nu.tibt", "Ch\u1eef s\u1ed1 T\u00e2y T\u1ea1ng" },
             { "ie", "Ti\u1ebfng Interlingue" },
-            { "%%GASCON", "GASCON" },
             { "ig", "Ti\u1ebfng Igbo" },
             { "ii", "Ti\u1ebfng Di T\u1ee9 Xuy\u00ean" },
             { "frm", "Ti\u1ebfng Ph\u00e1p Trung c\u1ed5" },
-            { "%%AO1990", "AO1990" },
             { "ik", "Ti\u1ebfng Inupiaq" },
             { "fro", "Ti\u1ebfng Ph\u00e1p c\u1ed5" },
             { "frp", "Ti\u1ebfng Arpitan" },
@@ -949,7 +903,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "is", "Ti\u1ebfng Iceland" },
             { "it", "Ti\u1ebfng Italy" },
             { "iu", "Ti\u1ebfng Inuktitut" },
-            { "%%CORNU", "CORNU" },
             { "ja", "Ti\u1ebfng Nh\u1eadt" },
             { "Mlym", "Ch\u1eef Malayalam" },
             { "Sarb", "Ch\u1eef Nam \u1ea2 R\u1eadp c\u1ed5" },
@@ -992,9 +945,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kw", "Ti\u1ebfng Cornwall" },
             { "ky", "Ti\u1ebfng Kyrgyz" },
             { "snk", "Ti\u1ebfng Soninke" },
-            { "Mult", "Mult" },
             { "la", "Ti\u1ebfng La-tinh" },
-            { "Hatr", "Hatr" },
             { "lb", "Ti\u1ebfng Luxembourg" },
             { "type.nu.mlym", "Ch\u1eef s\u1ed1 Malayalam" },
             { "lg", "Ti\u1ebfng Ganda" },
@@ -1037,10 +988,8 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "nl", "Ti\u1ebfng H\u00e0 Lan" },
             { "nn", "Ti\u1ebfng Na Uy (Nynorsk)" },
             { "no", "Ti\u1ebfng Na Uy" },
-            { "%%PROVENC", "PROVENC" },
             { "nr", "Ti\u1ebfng Ndebele Mi\u1ec1n Nam" },
             { "type.nu.modi", "Ch\u1eef s\u1ed1 Modi" },
-            { "Osge", "Osge" },
             { "nv", "Ti\u1ebfng Navajo" },
             { "kaa", "Ti\u1ebfng Kara-Kalpak" },
             { "ny", "Ti\u1ebfng Nyanja" },
@@ -1059,7 +1008,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kaw", "Ti\u1ebfng Kawi" },
             { "dtp", "Ti\u1ebfng Dusun Mi\u1ec1n Trung" },
             { "or", "Ti\u1ebfng Odia" },
-            { "Modi", "Modi" },
             { "os", "Ti\u1ebfng Ossetic" },
             { "%%ALALC97", "La M\u00e3 h\u00f3a ALA-LC, \u1ea5n b\u1ea3n n\u0103m 1997" },
             { "bpy", "Ti\u1ebfng Bishnupriya" },
@@ -1133,7 +1081,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sl", "Ti\u1ebfng Slovenia" },
             { "Gran", "Ch\u1eef Grantha" },
             { "sm", "Ti\u1ebfng Samoa" },
-            { "%%BASICENG", "BASICENG" },
             { "sn", "Ti\u1ebfng Shona" },
             { "so", "Ti\u1ebfng Somali" },
             { "type.nu.arab", "Ch\u1eef s\u1ed1 \u1ea2 R\u1eadp - \u1ea4n \u0110\u1ed9" },
@@ -1159,7 +1106,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "145", "T\u00e2y \u00c1" },
             { "tg", "Ti\u1ebfng Tajik" },
             { "th", "Ti\u1ebfng Th\u00e1i" },
-            { "%%SPANGLIS", "SPANGLIS" },
             { "ti", "Ti\u1ebfng Tigrinya" },
             { "bug", "Ti\u1ebfng Bugin" },
             { "kfo", "Ti\u1ebfng Koro" },
@@ -1175,7 +1121,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "swb", "Ti\u1ebfng C\u00f4mo" },
             { "Cakm", "Ch\u1eef Chakma" },
             { "tt", "Ti\u1ebfng Tatar" },
-            { "%%XSISTEMO", "XSISTEMO" },
             { "dyu", "Ti\u1ebfng Dyula" },
             { "tw", "Ti\u1ebfng Twi" },
             { "ty", "Ti\u1ebfng Tahiti" },
@@ -1191,7 +1136,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "Ital", "Ch\u1eef Italic c\u1ed5" },
             { "Kore", "Ch\u1eef H\u00e0n Qu\u1ed1c" },
             { "Zyyy", "Chung" },
-            { "uk", "Ti\u1ebfng Ucraina" },
+            { "uk", "Ti\u1ebfng Ukraina" },
             { "type.ca.coptic", "L\u1ecbch Copts" },
             { "ur", "Ti\u1ebfng Urdu" },
             { "%%1994", "Ph\u00e9p ch\u00ednh t\u1ea3 Resian Chu\u1ea9n h\u00f3a" },
@@ -1208,7 +1153,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "vi", "Ti\u1ebfng Vi\u1ec7t" },
             { "kho", "Ti\u1ebfng Khotan" },
             { "khq", "Ti\u1ebfng Koyra Chiini" },
-            { "key.hc", "Chu k\u1ef3 gi\u1edd (12 vs 24)" },
+            { "key.hc", "Chu k\u1ef3 gi\u1edd (12 v\u1edbi 24)" },
             { "%%TARASK", "Ph\u00e9p ch\u00ednh t\u1ea3 Taraskievica" },
             { "vo", "Ti\u1ebfng Volap\u00fck" },
             { "syc", "Ti\u1ebfng Syriac c\u1ed5" },
@@ -1217,7 +1162,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "quc", "Ti\u1ebfng K\u02bciche\u02bc" },
             { "type.nu.gonm", "Ch\u1eef s\u1ed1 Gonm" },
             { "qug", "Ti\u1ebfng Quechua \u1edf Cao nguy\u00ean Chimborazo" },
-            { "Newa", "Newa" },
             { "gaa", "Ti\u1ebfng Ga" },
             { "wa", "Ti\u1ebfng Walloon" },
             { "gag", "Ti\u1ebfng Gagauz" },
@@ -1240,13 +1184,11 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "mni", "Ti\u1ebfng Manipuri" },
             { "Latn", "Ch\u1eef La tinh" },
             { "Latg", "Ch\u1eef La-tinh Xc\u1ed1t-len" },
-            { "Nand", "Nand" },
             { "type.nu.hans", "Ch\u1eef s\u1ed1 c\u1ee7a ti\u1ebfng Trung gi\u1ea3n th\u1ec3" },
             { "type.nu.hant", "Ch\u1eef s\u1ed1 ti\u1ebfng Trung ph\u1ed3n th\u1ec3" },
             { "xh", "Ti\u1ebfng Xhosa" },
             { "type.nu.romanlow", "Ch\u1eef s\u1ed1 La M\u00e3 vi\u1ebft th\u01b0\u1eddng" },
             { "byn", "Ti\u1ebfng Blin" },
-            { "Dogr", "Dogr" },
             { "%%PAMAKA", "Ph\u01b0\u01a1ng ng\u1eef Pamaka" },
             { "Lyci", "Ch\u1eef Lycia" },
             { "osa", "Ti\u1ebfng Osage" },
@@ -1276,16 +1218,14 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "zu", "Ti\u1ebfng Zulu" },
             { "type.co.phonebook", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo danh b\u1ea1 \u0111i\u1ec7n tho\u1ea1i" },
             { "%%MONOTON", "\u0110\u01a1n \u00e2m" },
-            { "Geor", "Ch\u1eef Gruzia" },
+            { "Geor", "Ch\u1eef Georgia" },
             { "Shrd", "Ch\u1eef Sharada" },
-            { "%%LENGADOC", "LENGADOC" },
             { "kmb", "Ti\u1ebfng Kimbundu" },
             { "type.nu.jpanfin", "Ch\u1eef s\u1ed1 d\u00f9ng trong t\u00e0i ch\u00ednh c\u1ee7a ti\u1ebfng Nh\u1eadt" },
             { "Cham", "Ch\u1eef Ch\u0103m" },
             { "gez", "Ti\u1ebfng Geez" },
             { "Syrn", "Ch\u1eef \u0110\u00f4ng Syria" },
             { "type.nu.mymrshan", "Ch\u1eef s\u1ed1 Myanmar Shan" },
-            { "Elba", "Elba" },
             { "Narb", "Ch\u1eef B\u1eafc \u1ea2 R\u1eadp c\u1ed5" },
             { "type.nu.olck", "Ch\u1eef s\u1ed1 Ol Chiki" },
             { "type.co.reformed", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp \u0111\u00e3 s\u1eeda \u0111\u1ed5i" },
@@ -1301,20 +1241,15 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kok", "Ti\u1ebfng Konkani" },
             { "%%1901", "Ph\u00e9p ch\u00ednh t\u1ea3 Ti\u1ebfng \u0110\u1ee9c Truy\u1ec1n th\u1ed1ng" },
             { "kos", "Ti\u1ebfng Kosrae" },
-            { "%%PAHAWH2", "PAHAWH2" },
-            { "%%PAHAWH3", "PAHAWH3" },
-            { "%%PAHAWH4", "PAHAWH4" },
             { "type.nu.limb", "Ch\u1eef s\u1ed1 Limbu" },
             { "Sund", "Ch\u1eef Xu-\u0111\u0103ng" },
             { "kpe", "Ti\u1ebfng Kpelle" },
-            { "%%GRCLASS", "GRCLASS" },
             { "type.nu.khmr", "Ch\u1eef s\u1ed1 Kh\u01a1-me" },
             { "Tirh", "Ch\u1eef Tirhuta" },
             { "ilo", "Ti\u1ebfng Iloko" },
             { "%%VALENCIA", "Ti\u1ebfng Valencia" },
             { "Cprt", "Ch\u1ee9 S\u00edp" },
             { "%%BAKU1926", "B\u1ea3ng ch\u1eef c\u00e1i La-tinh Ti\u1ebfng Turk H\u1ee3p nh\u1ea5t" },
-            { "%%IJEKAVSK", "IJEKAVSK" },
             { "mua", "Ti\u1ebfng Mundang" },
             { "type.nu.guru", "Ch\u1eef s\u1ed1 Gurmukhi" },
             { "mul", "Nhi\u1ec1u Ng\u00f4n ng\u1eef" },
@@ -1330,8 +1265,8 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.tamldec", "Ch\u1eef s\u1ed1 Tamil" },
             { "krc", "Ti\u1ebfng Karachay-Balkar" },
             { "inh", "Ti\u1ebfng Ingush" },
+            { "fa_AF", "Ti\u1ebfng Dari" },
             { "krl", "Ti\u1ebfng Karelian" },
-            { "%%OXENDICT", "OXENDICT" },
             { "efi", "Ti\u1ebfng Efik" },
             { "key.nu", metaValue_key_nu },
             { "kru", "Ti\u1ebfng Kurukh" },
