@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,6 +70,30 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] GMT = new String[] {
+               "hora del meridiano de Greenwich",
+               "\u2205\u2205\u2205",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Cook = new String[] {
+               "hora est\u00e1ndar de las islas Cook",
+               "",
+               "hora de verano media de las islas Cook",
+               "",
+               "hora de las islas Cook",
+               "",
+            };
+        final String[] Wake = new String[] {
+               "hora de Isla Wake",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Cocos = new String[] {
                "hora de Islas Cocos",
                "",
@@ -78,6 +102,14 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] India = new String[] {
+               "hora de India",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "hora est\u00e1ndar de Isla de Pascua",
                "",
@@ -86,6 +118,54 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "hora de la Isla de Pascua",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "Hora Universal Coordinada",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Myanmar = new String[] {
+               "hora de Myanmar (Birmania)",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Norfolk = new String[] {
+               "hora est\u00e1ndar de la Isla Norfolk",
+               "",
+               "hora de verano de la Isla Norfolk",
+               "",
+               "hora de la Isla Norfolk",
+               "",
+            };
+        final String[] Solomon = new String[] {
+               "hora de Islas Salom\u00f3n",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Falkland = new String[] {
+               "hora est\u00e1ndar de las Islas Malvinas",
+               "",
+               "hora de verano de las Islas Malvinas",
+               "",
+               "hora de las Islas Malvinas",
+               "",
+            };
+        final String[] Macquarie = new String[] {
+               "hora de la Isla Macquarie",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Europe_Central = new String[] {
                "hora est\u00e1ndar de Europa central",
                "\u2205\u2205\u2205",
@@ -94,8 +174,24 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "hora de Europa central",
                "\u2205\u2205\u2205",
             };
-        final String[] Macquarie = new String[] {
-               "hora de la Isla Macquarie",
+        final String[] Europe_Eastern = new String[] {
+               "hora est\u00e1ndar de Europa del Este",
+               "\u2205\u2205\u2205",
+               "hora de verano de Europa del Este",
+               "\u2205\u2205\u2205",
+               "hora de Europa del Este",
+               "\u2205\u2205\u2205",
+            };
+        final String[] Europe_Western = new String[] {
+               "hora est\u00e1ndar de Europa del Oeste",
+               "\u2205\u2205\u2205",
+               "hora de verano de Europa del Oeste",
+               "\u2205\u2205\u2205",
+               "hora de Europa del Oeste",
+               "\u2205\u2205\u2205",
+            };
+        final String[] French_Southern = new String[] {
+               "hora de las Tierras Australes y Ant\u00e1rticas Francesas",
                "",
                "",
                "",
@@ -118,46 +214,6 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "hora de la monta\u00f1a",
                "",
             };
-        final String[] Wake = new String[] {
-               "hora de Isla Wake",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Falkland = new String[] {
-               "hora est\u00e1ndar de las Islas Malvinas",
-               "",
-               "hora de verano de las Islas Malvinas",
-               "",
-               "hora de las Islas Malvinas",
-               "",
-            };
-        final String[] Europe_Western = new String[] {
-               "hora est\u00e1ndar de Europa del Oeste",
-               "\u2205\u2205\u2205",
-               "hora de verano de Europa del Oeste",
-               "\u2205\u2205\u2205",
-               "hora de Europa del Oeste",
-               "\u2205\u2205\u2205",
-            };
-        final String[] Solomon = new String[] {
-               "hora de Islas Salom\u00f3n",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Norfolk = new String[] {
-               "hora de la Isla Norfolk",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marshall_Islands = new String[] {
                "hora de Islas Marshall",
                "",
@@ -166,286 +222,51 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Europe_Eastern = new String[] {
-               "hora est\u00e1ndar de Europa del Este",
-               "\u2205\u2205\u2205",
-               "hora de verano de Europa del Este",
-               "\u2205\u2205\u2205",
-               "hora de Europa del Este",
-               "\u2205\u2205\u2205",
-            };
-        final String[] GMT = new String[] {
-               "hora del meridiano de Greenwich",
-               "\u2205\u2205\u2205",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Myanmar = new String[] {
-               "hora de Myanmar (Birmania)",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] French_Southern = new String[] {
-               "hora de las Tierras Australes y Ant\u00e1rticas Francesas",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] India = new String[] {
-               "hora de India",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Cook = new String[] {
-               "hora est\u00e1ndar de las islas Cook",
-               "",
-               "hora de verano media de las islas Cook",
-               "",
-               "hora de las islas Cook",
-               "",
-            };
         final Object[][] data = new Object[][] {
             { "America/Denver", America_Mountain },
             { "America/Phoenix", America_Mountain },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Ljubljana", Europe_Central },
-            { "Pacific/Kwajalein", Marshall_Islands },
-            { "Europe/Berlin", Europe_Central },
-            { "Africa/Ouagadougou", GMT },
-            { "Africa/El_Aaiun",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Cairo", Europe_Eastern },
-            { "Pacific/Rarotonga", Cook },
-            { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/London", GMT },
-            { "Europe/Stockholm", Europe_Central },
-            { "Africa/Dakar", GMT },
-            { "Europe/Budapest", Europe_Central },
-            { "Europe/San_Marino", Europe_Central },
-            { "Europe/Zagreb", Europe_Central },
-            { "Europe/Helsinki", Europe_Eastern },
-            { "Asia/Beirut", Europe_Eastern },
-            { "Europe/Brussels", Europe_Central },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Ojinaga", America_Mountain },
-            { "Africa/Sao_Tome", GMT },
-            { "Europe/Warsaw", Europe_Central },
-            { "Europe/Tallinn", Europe_Eastern },
-            { "Europe/Jersey", GMT },
-            { "Asia/Damascus", Europe_Eastern },
-            { "Europe/Luxembourg", Europe_Central },
-            { "Europe/Belgrade", Europe_Central },
-            { "Africa/Bissau", GMT },
-            { "America/Yellowknife", America_Mountain },
-            { "Atlantic/Reykjavik", GMT },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Atlantic/St_Helena", GMT },
-            { "Africa/Ceuta", Europe_Central },
-            { "Europe/Guernsey", GMT },
-            { "Atlantic/Madeira", Europe_Western },
-            { "Africa/Timbuktu", GMT },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "Europe/Sofia", Europe_Eastern },
-            { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Isle_of_Man", GMT },
-            { "Africa/Nouakchott", GMT },
-            { "Europe/Prague", Europe_Central },
-            { "Antarctica/Troll", GMT },
-            { "Africa/Tunis", Europe_Central },
-            { "Europe/Andorra", Europe_Central },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "Africa/Banjul", GMT },
-            { "America/Inuvik", America_Mountain },
-            { "Antarctica/Macquarie", Macquarie },
-            { "Asia/Nicosia", Europe_Eastern },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "timezone.excity.Pacific/Wake", "Isla Wake" },
-            { "Europe/Lisbon", Europe_Western },
-            { "timezone.excity.Atlantic/Canary", "Islas Canarias" },
-            { "Europe/Oslo", Europe_Central },
-            { "Asia/Gaza", Europe_Eastern },
-            { "Atlantic/Faeroe", Europe_Western },
+            { "UTC", ETC_UTC },
+            { "ART", Europe_Eastern },
+            { "ECT", Europe_Central },
+            { "PNT", America_Mountain },
+            { "SST", Solomon },
             { "Etc/GMT", GMT },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Pacific/Easter", Easter },
-            { "Atlantic/Canary", Europe_Western },
-            { "Asia/Rangoon", Myanmar },
-            { "Europe/Bratislava", Europe_Central },
-            { "Africa/Lome", GMT },
-            { "Asia/Calcutta", India },
-            { "Africa/Freetown", GMT },
-            { "Europe/Copenhagen", Europe_Central },
-            { "Pacific/Norfolk", Norfolk },
-            { "Indian/Cocos", Cocos },
-            { "Europe/Malta", Europe_Central },
-            { "Europe/Vienna", Europe_Central },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "timezone.excity.America/Nassau", "Nas\u00e1u" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Busingen", Europe_Central },
-            { "Europe/Skopje", Europe_Central },
-            { "America/Edmonton", America_Mountain },
-            { "Europe/Podgorica", Europe_Central },
-            { "Europe/Sarajevo", Europe_Central },
-            { "Europe/Tirane", Europe_Central },
-            { "SystemV/MST7", America_Mountain },
-            { "Arctic/Longyearbyen", Europe_Central },
-            { "America/Fort_Nelson", America_Mountain },
-            { "Europe/Riga", Europe_Eastern },
-            { "Europe/Kiev", Europe_Eastern },
-            { "Europe/Rome", Europe_Central },
-            { "Asia/Hebron", Europe_Eastern },
-            { "Indian/Kerguelen", French_Southern },
-            { "Europe/Belfast", GMT },
-            { "Africa/Abidjan", GMT },
-            { "Africa/Monrovia", GMT },
-            { "Atlantic/Jan_Mayen", Europe_Central },
-            { "timezone.excity.America/Santiago", "Santiago" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Boise", America_Mountain },
-            { "America/Dawson_Creek", America_Mountain },
-            { "Africa/Algiers", Europe_Central },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "Pacific/Wake", Wake },
-            { "Europe/Zurich", Europe_Central },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "America/Shiprock", America_Mountain },
-            { "Africa/Bamako", GMT },
-            { "Europe/Amsterdam", Europe_Central },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Vatican", Europe_Central },
-            { "Africa/Accra", GMT },
-            { "timezone.excity.America/Fort_Nelson", "Fuerte Nelson" },
-            { "Europe/Gibraltar", Europe_Central },
-            { "Africa/Conakry", GMT },
+            { "Etc/UTC", ETC_UTC },
+            { "MST7MDT", America_Mountain },
+            { "Asia/Gaza", Europe_Eastern },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "Hora Universal Coordinada",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Madrid", Europe_Central },
+            { "Africa/Lome", GMT },
+            { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Hebron", Europe_Eastern },
+            { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Oslo", Europe_Central },
+            { "Europe/Riga", Europe_Eastern },
+            { "Europe/Rome", Europe_Central },
+            { "Africa/Accra", GMT },
+            { "Africa/Cairo", Europe_Eastern },
+            { "Africa/Ceuta", Europe_Central },
+            { "Africa/Dakar", GMT },
+            { "Africa/Tunis", Europe_Central },
+            { "Asia/Colombo", India },
+            { "Asia/Nicosia", Europe_Eastern },
+            { "Asia/Rangoon", Myanmar },
+            { "Europe/Malta", Europe_Central },
+            { "Europe/Sofia", Europe_Eastern },
+            { "Europe/Vaduz", Europe_Central },
+            { "Indian/Cocos", Cocos },
+            { "Pacific/Wake", Wake },
+            { "SystemV/MST7", America_Mountain },
+            { "Africa/Bamako", GMT },
+            { "Africa/Banjul", GMT },
+            { "Africa/Bissau", GMT },
+            { "America/Boise", America_Mountain },
+            { "Asia/Calcutta", India },
+            { "Asia/Damascus", Europe_Eastern },
+            { "Europe/Athens", Europe_Eastern },
+            { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
                 new String[] {
                     "hora del meridiano de Greenwich",
@@ -456,18 +277,91 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "Asia/Colombo", India },
-            { "Europe/Vaduz", Europe_Central },
-            { "MST7MDT", America_Mountain },
-            { "timezone.excity.America/St_Thomas", "Santo Tom\u00e1s" },
-            { "Pacific/Majuro", Marshall_Islands },
-            { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
-            { "Pacific/Guadalcanal", Solomon },
-            { "Europe/Athens", Europe_Eastern },
-            { "Atlantic/Stanley", Falkland },
-            { "America/Danmarkshavn", GMT },
+            { "Europe/Jersey", GMT },
+            { "Europe/Lisbon", Europe_Western },
+            { "Europe/London", GMT },
+            { "Europe/Madrid", Europe_Central },
             { "Europe/Monaco", Europe_Central },
+            { "Europe/Prague", Europe_Central },
+            { "Europe/Skopje", Europe_Central },
+            { "Europe/Tirane", Europe_Central },
+            { "Europe/Vienna", Europe_Central },
+            { "Europe/Warsaw", Europe_Central },
+            { "Europe/Zagreb", Europe_Central },
+            { "Europe/Zurich", Europe_Central },
+            { "Africa/Abidjan", GMT },
+            { "Africa/Algiers", Europe_Central },
+            { "Africa/Conakry", GMT },
+            { "Africa/Tripoli", Europe_Eastern },
+            { "America/Inuvik", America_Mountain },
+            { "Europe/Andorra", Europe_Central },
+            { "Europe/Belfast", GMT },
+            { "Europe/Tallinn", Europe_Eastern },
+            { "Europe/Vatican", Europe_Central },
+            { "Europe/Vilnius", Europe_Eastern },
+            { "Pacific/Easter", Easter },
+            { "Pacific/Majuro", Marshall_Islands },
+            { "Pacific/Tarawa", Gilbert_Islands },
+            { "Africa/Freetown", GMT },
+            { "Africa/Monrovia", GMT },
+            { "Africa/Sao_Tome", GMT },
+            { "Africa/Timbuktu", GMT },
+            { "America/Creston", America_Mountain },
+            { "America/Ojinaga", America_Mountain },
+            { "Atlantic/Canary", Europe_Western },
+            { "Atlantic/Faeroe", Europe_Western },
+            { "Europe/Belgrade", Europe_Central },
+            { "Europe/Brussels", Europe_Central },
+            { "Europe/Budapest", Europe_Central },
+            { "Europe/Busingen", Europe_Central },
+            { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Guernsey", GMT },
+            { "Europe/Helsinki", Europe_Eastern },
+            { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Uzhgorod", Europe_Eastern },
+            { "Pacific/Norfolk", Norfolk },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "America/Edmonton", America_Mountain },
+            { "America/Shiprock", America_Mountain },
+            { "Antarctica/Troll", GMT },
+            { "Atlantic/Madeira", Europe_Western },
+            { "Atlantic/Stanley", Falkland },
+            { "Europe/Amsterdam", Europe_Central },
+            { "Europe/Gibraltar", Europe_Central },
+            { "Europe/Ljubljana", Europe_Central },
+            { "Europe/Mariehamn", Europe_Eastern },
+            { "Europe/Podgorica", Europe_Central },
+            { "Europe/Stockholm", Europe_Central },
+            { "Indian/Kerguelen", French_Southern },
+            { "Africa/Nouakchott", GMT },
+            { "Europe/Bratislava", Europe_Central },
+            { "Europe/Copenhagen", Europe_Central },
+            { "Europe/Luxembourg", Europe_Central },
+            { "Europe/San_Marino", Europe_Central },
+            { "Europe/Zaporozhye", Europe_Eastern },
+            { "Pacific/Kwajalein", Marshall_Islands },
+            { "Pacific/Rarotonga", Cook },
+            { "Africa/Ouagadougou", GMT },
+            { "Atlantic/Jan_Mayen", Europe_Central },
+            { "Atlantic/Reykjavik", GMT },
+            { "Atlantic/St_Helena", GMT },
+            { "Europe/Isle_of_Man", GMT },
+            { "Europe/Kaliningrad", Europe_Eastern },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Yellowknife", America_Mountain },
+            { "Arctic/Longyearbyen", Europe_Central },
+            { "Pacific/Guadalcanal", Solomon },
+            { "America/Danmarkshavn", GMT },
+            { "America/Dawson_Creek", America_Mountain },
+            { "Antarctica/Macquarie", Macquarie },
+            { "America/Cambridge_Bay", America_Mountain },
+            { "timezone.excity.Pacific/Wake", "Isla Wake" },
+            { "timezone.excity.America/Nassau", "Nas\u00e1u" },
+            { "timezone.excity.Atlantic/Canary", "Islas Canarias" },
+            { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
+            { "timezone.excity.America/Santiago", "Santiago" },
+            { "timezone.excity.America/St_Thomas", "Santo Tom\u00e1s" },
+            { "timezone.excity.America/Fort_Nelson", "Fuerte Nelson" },
         };
         return data;
     }
